/* -*- Mode: C; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s): 
 */

.up
{
	list-style-image:url("chrome://global/skin/simple-arrow-up.gif");
	min-width: 0px;
}

.up[disabled="true"]
{
	list-style-image:url("chrome://global/skin/simple-arrow-up-disabled.gif");
}

.down
{
	min-width: 0px;
	list-style-image:url("chrome://global/skin/simple-arrow-down.gif");
}

.down[disabled="true"]
{
	list-style-image:url("chrome://global/skin/simple-arrow-down-disabled.gif");
}

/*
#add-button
  {
    list-style-image      : url("chrome://global/skin/simple-arrow-right.gif");
  }
  
#remove-button
  {
    list-style-image      : url("chrome://global/skin/simple-arrow-left.gif");
  }
*/