#mini-nav 
  {
	  list-style-image      : url("chrome://global/skin/taskbar-navigator.gif");
  }

#mini-nav:hover
  {
    list-style-image      : url("chrome://global/skin/taskbar-navigator-hover.gif");
  }

#mini-mail 
  {
	  list-style-image      : url("chrome://global/skin/taskbar-mail.gif");
  }

#mini-mail:hover
  {
    list-style-image      : url("chrome://global/skin/taskbar-mail-hover.gif");
  }

#mini-mail[BiffState="NewMail"]
  {
    list-style-image      : url("chrome://global/skin/taskbar-gotmail.gif");
  }

#mini-mail[BiffState="NewMail"]:hover
  {
    list-style-image      : url("chrome://global/skin/taskbar-gotmail-hover.gif");
  }

#mini-addr 
  {
	  list-style-image      : url("chrome://global/skin/taskbar-addressbook.gif");
  }

#mini-addr:hover
  {
    list-style-image      : url("chrome://global/skin/taskbar-addressbook-hover.gif");
  }

#mini-comp 
  {
	  list-style-image      : url("chrome://global/skin/taskbar-composer.gif");
  }

#mini-comp:hover
  {
    list-style-image      : url("chrome://global/skin/taskbar-composer-hover.gif");
  }

.taskbutton 
  {
	  margin-right          : 3px ! important;
  }

.taskbutton > .button-internal-box > .button-text-container 
  {
    display               : none;
  }  
  
.taskbarspacer 
  {
    min-width             : 0.3em;
    width                 : 1em;
  }
  
/* hide goto menu bug #47633 */ 
#taskbarGotoMenuBox{
	display:none;	
}   
