
titledbox
  {
    border                : 2px groove #CCCCCC;
    padding               : 7px;
    margin                : 5px;
  }

title
  {
    margin                : 0px 6px 2px 6px;
    padding               : 0px 3px 0px 3px;
    background-color      : #CCCCCC; 
  }

.titledbox-body
  {
    display               : block;
    padding               : inherit;
  }

    
/** box formatting **/
  box[autostretch="never"]
    {
      vertical-align      : middle;
    }
    
  box[autostretch="never"][valign="top"]
    {
      vertical-align      : top;
    }
    
  box[autostretch="never"][valign="bottom"]
    {
      vertical-align      : bottom;
    }
    
  box[autostretch="never"][halign="center"] 
    {
      text-align          : center;
    }
    
  box[autostretch="never"][halign="right"]
    {
      text-align          : right;
    }

  row
    {
      vertical-align      : middle;
    }
  