/* colors */

.color-dialog
  {
    background-color      : ThreeDFace;
    color                 : windowtext;
  }
  
.color-window
  {
    background-color      : window;
    color                 : windowtext;
  }

/* inset areas */
.inset
  {
    border-left           : 1px solid ThreeDShadow;
    border-top            : 1px solid ThreeDShadow;
    border-right          : 1px solid ThreeDHighlight;
    border-bottom         : 1px solid ThreeDHighlight;
    margin                : 0px 5px 5px 5px;
  }
  
/* formatting */
.groove-top
  {
    border-top            : 2px groove ThreeDFace;  
  }
  
.groove-right
  {
    border-right          : 2px groove ThreeDFace;
  }
  
.groove-left
  {
    border-left           : 2px groove ThreeDFace;
  }
  
.groove-bottom
  {
    border-bottom         : 2px groove ThreeDFace;
  }
  
.outset
  {
    border-left           : 1px solid ThreeDHighlight;
    border-top            : 1px solid ThreeDHighlight;
    border-right          : 1px solid ThreeDShadow;
    border-bottom         : 1px solid ThreeDShadow;
  }  
  
/** separator rules **/
/* standard separators */
  separator, separator[orient="horizontal"] 
    {
      height: 1.5em;
    }
  
  separator[orient="vertical"] 
    {
      width: 1.5em;
    }

/* thinner separators (50% size) */
  separator.thin, separator.thin[orient="horizontal"] 
    {
      height: 0.5em;
    }
  
  separator.thin[orient="vertical"] 
    {
      width: 0.5em;
    }

/* groove separators (50% size) */
  separator.groove,
  separator.groove[orient="horizontal"] 
    {
      border-top: 1px solid ThreeDShadow;
      border-bottom: 1px solid ThreeDHighlight;
      height: 0px;
      margin-top: 0.4em;
      margin-bottom: 0.4em;
    }
  
  separator.groove[orient="vertical"] 
    {
      border-left: 1px solid ThreeDShadow;
      border-right: 1px solid ThreeDHighlight;
      margin-left: 0.4em;
      margin-right: 0.4em;
    }
  
/* groove separators (0 padding, for dividing effects) */  
  separator.groove-thin 
    {
      border-top: 1px solid ThreeDShadow;
      border-bottom: 1px solid ThreeDHighlight;
      height: 0px;
    }
  
  separator[orient="vertical"].groove-thin 
    {
      border-left: 1px solid ThreeDShadow;
      border-right: 1px solid ThreeDHighlight;
    }

/** text formatting rules **/
/* label (with margins) */
  text.label 
    {
      margin              : 1px 5px 2px 6px;
    }
    
  text[disabled="true"] 
    {
      color                 : GrayText;
    }    
    
  html
    {
      margin              : 1px 5px 4px 5px;
      cursor              : default;
    }

  .header 
    {
      font-weight         : bold;
    }
   
  .indent
    {
      margin-left         : 23px;
    }

  .icon-dropmarker
    {
      list-style-image    : url("chrome://global/skin/dropmarker-down-on.gif");
    }
    
  .box-padded
    {
      padding             : 5px;
    }    

  .spaced
    {
      margin              : 3px 5px 4px 5px;
    }    

  .wizard-box
    {
      padding             : 20px 44px 10px 44px;
    }    
    
/* Double Border Boxes */

  /* top only */
  .double-box-top
    {
      -moz-binding        : url("chrome://global/skin/classicBindings.xml#double-box");
      border-top          : 1px solid ThreeDShadow;
      background-color    : #FFFFFF;
      margin              : 0px;
    }
  
  .double-box-top > .db-internal-box
    {
      border-top          : 1px solid ThreeDDarkShadow;
    }          
    
  /* all round */    
  .double-box
    {
      -moz-binding          : url("chrome://global/skin/classicBindings.xml#double-box");
      border-left           : 1px solid ThreeDShadow;
      border-top            : 1px solid ThreeDShadow;
      border-bottom         : 1px solid ThreeDHighlight;
      border-right          : 1px solid ThreeDHighlight;
      background-color      : #FFFFFF;
      margin                : 0px;
    }
  
  .double-box > .db-internal-box
    {
      border                : 1px solid ThreeDDarkShadow;
    }   
