/**  
 * Small Dialog Header (without icon)
 **/
.box-smallheader 
  {
    -moz-binding          : url(chrome://communicator/content/dialogBindings.xml#smallheader);
    border-left           : 1px solid ThreeDShadow;
    border-top            : 1px solid ThreeDShadow;
    border-right          : 1px solid ThreeDHighlight;
    border-bottom         : 1px solid ThreeDHighlight;
    margin                : 0px 5px 6px 5px;
  }

.box-smallheader > .toolbar-primary
  {
    padding               : 0px 0px 3px 0px;
    min-height            : 0px;
    background-image      : url(chrome://communicator/skin/smallheader-bg.gif);
  }

.box-smallheader-left 
  {
    font-size             : larger;
    font-weight           : bold;
    padding-left          : 6px;
  }

.box-smallheader-right 
  {
    padding-right         : 6px;
  }

.box-smallheader > .toolbar-primary 
  {
    border                : 1px solid ThreeDDarkShadow;
    vertical-align        : middle;
    padding-top           : 3px;
  }


/** 
 * Large Dialog Header (with icon) 
 **/
.box-header 
  {
    -moz-binding          : url(chrome://global/skin/classicBindings.xml#largeheader);
    border-bottom         : 1px solid ThreeDHighlight;
  }

.largeheader-box
  {
    background-color      : window;
    border-bottom         : 1px solid ThreeDShadow;
  }  
  
.largeheader-header-text
  {
    font-weight           : bold;
    margin-left           : 23px;
  }

.largeheader-desc-text
  {
    margin-left           : 44px;
  }  

.largeheader-icon
  {
    width                 : 49px;
    height                : 49px;
    margin                : 5px;
  }  
  
/**
 * Dialog status line (blue) including progress area
 **/
.box-status 
  {
    visibility            : collapse;
  }

/** 
 * Utility classes for use when combined headers/footers are used
 **/
/* display area framed container */
#contentarea 
  {
    border-top            : 2px groove ThreeDFace;
    border-bottom         : 2px groove ThreeDFace;
    padding               : 7px;
  }

