/**  
 * Small Dialog Header (without icon)
 **/
.box-smallheader 
  {
    -moz-binding          : url(chrome://communicator/content/dialogBindings.xml#smallheader);
    border                : 1px inset #CCCCCC;
    margin                : 0px 5px 6px 5px;
  }

.toolbar-primary
  {
    padding               : 0px 0px 3px 0px;
    min-height            : 0px;
  }

.box-smallheader-left 
  {
    font-size             : larger;
    font-weight           : bold;
    color                 : #FFFFFF;
    padding-left          : 6px;
  }

.box-smallheader-right 
  {
    color                 : #FFFFFF;
    padding-right         : 6px;
  }

.box-smallheader > .toolbar-primary 
  {
    border                : 1px solid #000000;
    vertical-align        : middle;
    padding-top           : 3px;
  }

/** 
 * Large Dialog Header (with icon) 
 **/
.box-header 
  {
    -moz-binding          : url(chrome://communicator/content/dialogBindings.xml#largeheader);
  }

.box-header-header 
  {
    padding               : 0px 0px 4px 5px;
    min-height            : 34px;
  }

.box-header-text-box 
  {
    vertical-align        : middle;
  }

.box-header-text 
  {
    color                 : white;
    font-size             : large;
    font-weight           : bold;
    text-decoration       : underline;
  }

.box-header-icon-box  
  {
    vertical-align        : middle;
  }
  
.box-header-circle-box
  {
    background-image      : url("chrome://global/skin/button28-bg.gif");
    background-repeat     : no-repeat;
    background-position   : 50% 4px;
    background-color      : transparent;
    min-width             : 28px;
    min-height            : 32px;
    margin                : 1px 7px 1px 1px;
    text-align            : center;
  }  

/**
 * Dialog status line (blue) including progress area
 **/
.box-status 
  {
    -moz-binding          : url(chrome://communicator/content/dialogBindings.xml#status);
  }

.box-status-bg 
  {
    padding               : 1px 5px 1px 5px;
    min-height            : 0px ! important;
  }

.box-status-text, .box-status-progress
  {
    color                 : #99cccc ! important;
  }

  
/** 
 * Utility classes for use when combined headers/footers are used
 **/
/* display area framed container */
#contentarea 
  {
    border-top            : 2px groove #CCCCCC;
    border-bottom         : 2px groove #CCCCCC;
    padding               : 7px;
  }

/* top border on status area */
#wizardButtons 
  {
    border-bottom         : 1px outset #CCCCCC;
    padding-top           : 1px;
    padding-bottom        : 1px;
  }


