/* outer frame */
  menulist 
    {
      -moz-binding        : url("chrome://global/skin/menulistBindings.xml#menulist");
      border-left         : 1px solid ThreeDShadow;
      border-top          : 1px solid ThreeDShadow;
      border-right        : 1px solid ThreeDHighlight;
      border-bottom       : 1px solid ThreeDHighlight;
      background-color    : -moz-field;
      color               : WindowText;
      margin              : 1px 5px 2px 5px;
    }
    
  menulist[disabled="true"]
    {
      background-color    : ThreeDFace;
      color               : GrayText;
    }
    
/* icon display frame */
  .menulist-internal-box
    {
      border-left         : 1px solid ThreeDDarkShadow;
      border-top          : 1px solid ThreeDDarkShadow;
      border-right        : 1px solid ThreeDLightShadow;
      border-bottom       : 1px solid ThreeDLightShadow;
      -moz-user-focus     : ignore;
    }  

  .menulist-display-box,
  menulist[open="true"]:focus > .menulist-internal-box > .menulist-display-box
    {
      border              : 1px solid transparent;
      margin              : 1px;
      background-color    : -moz-field;
      color               : WindowText;
    }     
    
  menulist:focus > .menulist-internal-box > .menulist-display-box
    {
      border              : 1px dotted HighlightText;
      background-color    : Highlight;
      color               : HighlightText;
    }
      
/* text display frame */
  .menulist-text 
    {
      padding             : 0px 2px 0px 2px;
      margin              : 0px;
    }
    
/* drop marker display frame */
  .menulist-dropmarker-box-1
    {
      border-top          : 1px solid ThreeDFace;
      border-right        : 1px solid ThreeDDarkShadow;
      border-bottom       : 1px solid ThreeDDarkShadow;
      border-left         : 1px solid ThreeDFace;
      background-color    : ThreeDFace;
    }
  
  .menulist-dropmarker-box-2
    {
      border-top          : 1px solid ThreeDHighlight;
      border-right        : 1px solid ThreeDShadow;
      border-bottom       : 1px solid ThreeDShadow;
      border-left         : 1px solid ThreeDHighlight;
      padding             : 2px 1px 2px 1px;
    }

  .menulist-dropmarker
    {
      list-style-image    : url("chrome://global/skin/scroll-down.gif");
    }
  
  .menulist-dropmarker[disabled="true"]
    {
      list-style-image    : url("chrome://global/skin/scroll-down-disabled.gif");
    }

  menulist:hover:active > .menulist-internal-box > .menulist-dropmarker-box-1[open="true"]
    { 
      border              : 1px solid ThreeDShadow;
    }
    
  menulist:hover:active > .menulist-internal-box > .menulist-dropmarker-box-1 > .menulist-dropmarker-box-2[open="true"]
    {
      border              : 1px solid ThreeDFace;
      padding             : 3px 0px 1px 2px;
    }

/* rules for popups and separators associated with menulists */

  menulist > menupopup 
    {
      -moz-binding        : url("chrome://global/skin/menulistBindings.xml#menulistpopup");
      border              : 1px solid WindowText;
      min-width           : 0px;
      background-color    : -moz-field;
    }

  menulist > menupopup > menuitem,
  menulist > menupopup > menu
    {
      border              : 1px solid transparent;
      padding             : 0px 7px !important;
      min-width           : 0px;  /* should be in content*/
      max-width           : none; /* should be in content*/
      font                : message-box;
      color               : WindowText;
    }

  menulist > menupopup > menuitem > .menu-iconic-accel,
  menulist > menupopup > menuitem > .menu-accel,
  menulist > menupopup > menuitem > .menu-text,
  menulist > menupopup > menuitem > .menu-iconic-text,
  menulist > menupopup > menu > .menu-text,
  menulist > menupopup > menu > .menu-accel,
  menulist > menupopup > menu > .menu-iconic-text,
  menulist > menupopup > menu > .menu-iconic-accel
    {
      margin-top          : 0px;
      margin-bottom       : 0px;
    }

  menulist > menupopup > menuitem[menuactive="true"],
  menulist > menupopup > menuitem[selected="true"]
    {
      border              : 1px dotted #F5DB95;
    }

  menulist > menupopup > menuitem > .menu-iconic-left,
  menulist > menupopup > menuitem > .menu-iconic-left[menuactive="true"]
    {
      list-style-image    : inherit;
      width               : 0px;
      border              : none;
    }

  menulist > menupopup > menuseparator
    {
      border-top: none;
      border-bottom: 1px solid WindowText;
    }
    
/**
 * <menulist>s for things like mailnews addressing widget
 **/
 
  .menulist-compact
    {
      -moz-binding        : url("chrome://global/skin/menulistBindings.xml#menulist-compact");
      margin              : 0px;
      border-top          : 1px solid ThreeDHighlight;
      border-right        : 1px solid ThreeDDarkShadow;
      border-bottom       : 1px solid ThreeDDarkShadow;
      border-left         : 1px solid ThreeDHighlight;
      background-color    : ThreeDFace;
      -moz-user-focus     : ignore;  
    }    
    
  .menulist-compact-internal-box
    {
      border-top          : 1px solid ThreeDLightShadow;
      border-right        : 1px solid ThreeDShadow;
      border-bottom       : 1px solid ThreeDShadow;
      border-left         : 1px solid ThreeDLightShadow;
    }
    
  .menulist-compact-dropmarker
    {
      list-style-image    : url("chrome://global/skin/scroll-down.gif");
      margin-left         : 2px;
    }
    
  .menulist-compact-text
    {
      margin-right        : 3px;
    }  

  .menulist-compact:hover:active,
  .menulist-compact[open="true"]
    {
      border              : 1px solid ThreeDDarkShadow;
      background-color    : ThreeDShadow;
      color               : ThreeDHighlight;
    }

  .menulist-compact:hover:active > .menulist-compact-internal-box,
  .menulist-compact[open="true"] > .menulist-compact-internal-box 
    {
      border              : 1px solid transparent;
    }
    
/**
 * Editable menulists (comboboxes) 
 */
  
menulist[editable="true"] 
  {
    -moz-binding          : url("chrome://global/skin/menulistBindings.xml#menulist-editable") !important;
  }
   
.menulist-editable-text 
  {
    border                : none !important;
    margin                : 0px !important;
  }

menulist[editable="true"] > .menulist-internal-box > .menulist-display-box
  {
    margin                : 0px;
  }

menulist[editable="true"]:focus > .menulist-internal-box > .menulist-display-box
  {
    border                : none !important;
  }
