/* 
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *  
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *  
 * The Original Code is Mozilla Communicator client code.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 *   Don Bragg (dbragg@netscape.com) 12/08/1999
 *   Blake Ross (BlakeR1234@aol.com)  6/12/2000
 */

@import url(chrome://global/skin);


div.label {
  margin                    : 3px;
}

div#tree-housing {
  height                    : 3em;
}

box#mainBox{
  margin                    : 5px;
}

box#okcancelBox{
  margin-left               : 22em;
  margin-top                : 3px;
  margin-bottom             : 3px;
}


box#treeBox{
  height                    : 18ex;
  margin                    : 0em;
}

box#statusMessages{
  width                     : 36em;
}


/*
div#table-housing {
  height                    : 100%;
}
*/

tree#modulesTree {
  background-color          : transparent ! important;
  height                    : 16ex;
  width                     : 32em;
}

treecell#moduleName {
  width                     : 50%
}

treecell#moduleSource {
  width                     : 50%;
}
tree > treechildren {
  background-color          : window ! important;
}

tree#modulesTree > treehead > treerow > treecell {
  padding-left              : 1px;
  padding-right             : 1px;
  border-left               : none;
  border-top                : none;
  border-right              : none;
  background-color          : transparent ! important;
  color                     : windowtext;
}

spring#verticalSmallSpacer {
  height                    : 1ex;
}

spring#verticalLargeSpacer {
  height                    : 6ex;
}

spring#verticalMediumSpacer {
  height                    : 3ex;
}

spring#horizontalSmallSpacer {
  width                     : 2em;
}

spring#horizontalLargeSpacer {
  width                     : 10em;
}

.headline {
  font-size                 : 2em;
  margin                    : 4px;
  font-weight               : bold;
}