
/******** Tree widget **********/

/** basic tree ****************************************************
 *  basic tree widget for use in main windows where no decoration
 *  is required.
 **/
tree {
  border: none;
  border-spacing: 0px;
  background-color: #ffffff;
  color: #000000;
}

/** class="inset" *************************************************
 *  this is the tree class used by dialogs to create treeviews with 
 *  inset borders, and default dialog spacing.
 **/
tree.inset {
  border-top: 1px solid #666666;
  border-bottom: 1px solid white;
  border-left: 1px solid #666666;
  border-right: 1px solid white;
  margin: 1px 5px 2px 5px;
}

treecell { 
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
  padding: 0px 0px 1px 2px;
  white-space: nowrap;
  vertical-align: middle;
} 

.treecell-header, 
.treecell-inset-header, 
.treecell-header-image { 
  border-left: 1px solid #EDEDED !important;
  border-top: 1px solid #EDEDED !important;
  border-right: 1px solid #6E7070 !important;
  border-bottom: 1px solid #6E7070 !important;
  padding: 0px;
  background-color: #C2D0D0; 
  color: #000000;
}

.treecell-header-box,
.treecell-header-image-box {
  border-left: 1px solid #C2D0D0;
  border-top: 1px solid #C2D0D0;
  border-right: 1px solid #A4ACAC;
  border-bottom: 1px solid #A4ACAC;
  vertical-align: middle;
}  

.treecell-header-box {
  padding: 0px 4px 0px 4px;
}

.treecell-header-image-box {
  padding: 0px 1px 0px 1px;
}
  
.treecell-header:hover:active,
.treecell-header-image:hover:active,
.treecell-inset-header:hover:active {
  border: 1px solid #A4ACAC !important;
}

.treecell-header:hover:active > .treecell-header-box,
.treecell-inset-header:hover:active > .treecell-header-box,
.treecell-header-image:hover:active > .treecell-header-image-box {
  border-top: 1px solid transparent;
  border-right: none;
  border-bottom: none;
  border-left: 1px solid transparent;
}
  
.treecell-header:hover:active > .treecell-header-box,
.treecell-inset-header:hover:active > .treecell-header-box {
  padding: 1px 4px 0px 5px;
}

.treecell-header-image:hover:active > .treecell-header-image-box {
  padding: 1px 1px 0px 2px;
}

.treecell-image {
  padding: 0px;
}

/** class="propertylist" ******************************************
 *  class for cells in grid-formatted property lists.
 **/
treecell.propertylist {
  padding-left: 5px;
  border-right: 1px solid #CCCCCC;
  border-bottom: 1px solid #CCCCCC;
}

.tree-cell-primary-icon {
  list-style-image: inherit;
  padding-right: 2px;
}

.tree-cell-icon {
  list-style-image: inherit;
  padding-right: 2px;
}

.treecell-indent > .tree-cell-primary-icon {
  padding-left: 14px;
 }

treeitem[container="true"] > treerow > .treecell-indent > .tree-cell-primary-icon {
  padding-left: 0px;
}

.tree-cell-twisty {
 list-style-image: url("chrome://global/skin/closedtwisty.gif");
 -moz-user-focus:ignore;
 padding-right: 2px;
}

treehead > treeitem > treerow,
treehead > treerow {
  border: none;
}

treerow {
  border-right: 1px solid transparent;
  border-left: 1px solid transparent;
}

treeitem[selected="true"] > treerow {
 color: #000000;
 background-color: #CCCCCC;
}

tree:focus > treechildren treeitem[selected="true"] > treerow,
treeitem[dd-dropon="true"] > treerow {
  color: #ffffff;
	background-color: #486380;
}

tree:focus > treechildren treeitem[selected="true"][current="true"] > treerow,
tree:focus > treechildren treeitem[selected="true"][current="true"] > treerow > treecell {
  border-color: #768AA0;
}

.tree-cell-twisty:hover {
 text-decoration: none;
}

.tree-cell-twisty:active {
 text-decoration: none;
}

.tree-cell-twisty[disabled="true"] {
 list-style-image: none;
}

treeitem[container="true"][open="true"] > treerow > treecell > .tree-cell-twisty {
 list-style-image: url("chrome://global/skin/opentwisty.gif");
}

/* tree header with sort direction indicators */

.tree-header-sortdirection {
  list-style-image: none;
}

.sortDirectionIndicator[sortDirection="ascending"] > .treecell-header-box > .tree-header-sortdirection {
  list-style-image: url("chrome://global/skin/sortAscending.gif");
}

.sortDirectionIndicator[sortDirection="descending"] > .treecell-header-box > .tree-header-sortdirection {
  list-style-image: url("chrome://global/skin/sortDescending.gif");
}

.treecell-popup-icon
  {
    list-style-image       : url("chrome://global/skin/columnselect.gif");
  }
