/*
The contents of this file are subject to the Netscape Public
License Version 1.1 (the "License"); you may not use this file
except in compliance with the License. You may obtain a copy of
the License at http://www.mozilla.org/NPL/

Software distributed under the License is distributed on an "AS
IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
implied. See the License for the specific language governing
rights and limitations under the License.

The Original Code is Mozilla Communicator client code, released
March 31, 1998.

The Initial Developer of the Original Code is Netscape
Communications Corporation. Portions created by Netscape are
 Copyright (C) 1998-1999 Netscape Communications Corporation. All
Rights Reserved.
*/


/* These are the style attributes we are applying to the message header
 * view overlay which shows the message headers for a selected message.
 * some of this stuff originated from mailheaders.css
 */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to HTML */
@namespace html url("http://www.w3.org/1999/xhtml"); /* namespace for XUL elements */

mail-emailaddress 
  {
    -moz-binding          : url(chrome://messenger/content/mailWidgets.xml#mail-emailaddress);
    display               : inline;
  }

.buttonTopSpacer     
  { 
    height                : 0.3em; 
  }

.buttonSpacer        
  { 
    width                 : 0.5em; 
  }

.headerValueBox 
  { 
    width                 : 7.7em;
    text-align            : right;
  }

.headerBox              
  { 
    overflow              : hidden; 
    min-width             : 50px;
  }

#addToAddressBookButton 
  {
	  list-style-image      : url("chrome://messenger/skin/addtoab.gif");
    min-height            : 20px;
    margin                : 0px;
  }

#attachmentButton 
  {
    list-style-image      : url("chrome://messenger/skin/attach.gif");
    min-height            : 20px;
    margin                : 0px;
  }

.emailDisplayImage
  {
    align                 : right;
  }

.emailSeparator 
  {
    display               : inline;
  }

.emailDisplayButton 
  {
    color                 : blue;
    text-decoration       : underline;
    cursor                : pointer;
    max-height            : 15px;
  }

.showMoreAddressesButton 
  {
    list-style-image      : url("chrome://messenger/skin/more.gif");
    display               : inline;
  }

.showFewerAddressesButton 
  {
    list-style-image      : url("chrome://messenger/skin/less.gif");
    display               : inline;
  }

html.headerValue   
  { 
    white-space           : normal;
    min-width             : 50px; 
    margin                : 0px;
  }

html.subjectvalue  
  { 
    font-weight           : bold; 
  }

text.headerdisplayname 
  { 
    font-weight           : bold; 
    margin-right          : 0.5em; 
    margin-left           : 0.5em; 
    min-height            : 18px 
  }

text.headerValue 
  { 
    white-space           : normal; 
    min-width             : 50px; 
  }
  
#msgHeaderView
  {
    border-left           : none;
    border-right          : none;
  }
  
#headerPart1
  {
    background-image      : url("chrome://global/skin/scrollbar-slider-bg.gif");
  }
      
