/** The largest type of toolbar buttons. In the Seamonkey implementation, 
 *  these are only used in the navigation toolbar in the navigator package.
 **/
 
  /* outer frame */
  .button-toolbar-1, .button-toolbar-2
    {
      -moz-binding        : url("chrome://global/content/xulBindings.xml#buttontop");
      min-width           : 47px;
      margin              : 0px;
      border              : 1px solid transparent;
      color               : WindowText;
      background-color    : transparent;
      -moz-user-focus     : ignore;
    }

  .button-toolbar-1:hover, .button-toolbar-2:hover
    {
      border              : 1px solid ThreeDDarkShadow;
      color               : #0000FF;
    } 
    
  .button-toolbar-1 > .button-internal-box,
  .button-toolbar-2 > .button-internal-box
    {
      padding             : 2px 7px 2px 6px;
      vertical-align      : middle;
      text-align          : center;
      border              : 1px solid transparent;
    }    
    
  .button-toolbar-1[disabled="true"],
  .button-toolbar-1[disabled="true"]:hover,
  .button-toolbar-1[disabled="true"]:hover:active,
  .button-toolbar-2[disabled="true"],
  .button-toolbar-2[disabled="true"]:hover,
  .button-toolbar-2[disabled="true"]:hover:active
    {
      border              : 1px solid transparent;
      color               : GrayText;
    }

  .button-toolbar-1[disabled="true"]:hover:active > .button-internal-box,
  .button-toolbar-2[disabled="true"]:hover:active > .button-internal-box
    {
      color               : GrayText;
    }

  .button-toolbar-1:hover > .button-internal-box,
  .button-toolbar-2:hover > .button-internal-box
    {
      border-left         : 1px solid ThreeDHighlight;
      border-top          : 1px solid ThreeDHighlight;
      border-right        : 1px solid ThreeDShadow;
      border-bottom       : 1px solid ThreeDShadow;
    }

  .button-toolbar-1:hover:active > .button-internal-box,
  .button-toolbar-2:hover:active > .button-internal-box
    {
      padding             : 3px 6px 1px 7px;
      border-left         : 1px solid ThreeDShadow !important;
      border-top          : 1px solid ThreeDShadow !important;
      border-right        : 1px solid ThreeDHighlight !important;
      border-bottom       : 1px solid ThreeDHighlight !important;
      color               : #000080;
    }
    
  .button-toolbar-1[disabled="true"] > .button-internal-box,
  .button-toolbar-1[disabled="true"]:hover > .button-internal-box,
  .button-toolbar-1[disabled="true"]:hover:active > .button-internal-box,
  .button-toolbar-2[disabled="true"] > .button-internal-box,
  .button-toolbar-2[disabled="true"]:hover > .button-internal-box,
  .button-toolbar-2[disabled="true"]:hover:active > .button-internal-box
    {
      padding             : 2px 7px 2px 6px !important;
      border              : 1px solid transparent !important;
    }

  .button-toolbar-1 > .button-internal-box > .button-text-container,
  .button-toolbar-2 > .button-internal-box > .button-text-container
    {
      text-align          : center;
    }
          
/**
 * Standard Toolbar Buttons
 *   for secondary command toolbars, e.g. formatting toolbar 
 **/
  .button-toolbar
    {
      -moz-binding        : url("chrome://global/content/xulBindings.xml#buttonleft");
      margin              : 1px; 
      border              : 1px solid transparent;
      min-width           : 0px;
      max-width           : 14em;
      color               : WindowText;
      -moz-user-focus     : ignore;
    }

  .button-toolbar > .button-internal-box
    {
      border              : 1px solid transparent;
  	  padding             : 1px 3px 1px 3px;
    }
    
  /* toggled toolbar styles (editor formatting toolbars, etc) */
  .button-toolbar[toggled="true"] > .button-internal-box
    {
      border-left         : 1px solid ThreeDShadow;
      border-top          : 1px solid ThreeDShadow;
      border-right        : 1px solid ThreeDHighlight;
      border-bottom       : 1px solid ThreeDHighlight;
      background-color	  : ThreeDHighlight;
    }
    
  .button-toolbar[toggled="true"]:hover > .button-internal-box
    {
      border-left         : 1px solid ThreeDShadow;
      border-top          : 1px solid ThreeDShadow;
      border-right        : 1px solid ThreeDHighlight;
      border-bottom       : 1px solid ThreeDHighlight;
      background-color	  : ThreeDFace;
      background-image    : none;
    }
    
  .button-toolbar[value] > .button-internal-box > .button-text-container
    {
      padding-left        : 4px;
    }    

  .button-toolbar:hover
    {
      border              : 1px solid ThreeDDarkShadow;
    }
    
  .button-toolbar:hover > .button-internal-box
    { 
      border-left         : 1px solid ThreeDHighlight;
      border-top          : 1px solid ThreeDHighlight;
      border-right        : 1px solid ThreeDShadow;
      border-bottom       : 1px solid ThreeDShadow;
      color               : #0000FF;
    }
    
  .button-toolbar:hover:active > .button-internal-box
    {
      padding             : 2px 2px 0px 4px;
      border-left         : 1px solid ThreeDShadow;
      border-top          : 1px solid ThreeDShadow;
      border-right        : 1px solid ThreeDHighlight;
      border-bottom       : 1px solid ThreeDHighlight;
      color               : #000080;
    }
    
  .button-toolbar[disabled="true"],
  .button-toolbar[disabled="true"]:hover,
  .button-toolbar[disabled="true"]:hover:active    
    {
      color               : GrayText;
      border              : 1px solid transparent;
    }

  .button-toolbar[disabled="true"] > .button-internal-box,
  .button-toolbar[disabled="true"]:hover > .button-internal-box,
  .button-toolbar[disabled="true"]:hover:active > .button-internal-box
    {
  	  padding             : 1px 3px 1px 3px !important;
    }
    
/**
 * Low profile toolbar buttons
 *   e.g. taskbar
 **/
  .button-toolbar-4    
    {
      background-color    : transparent;
      -moz-binding        : url("chrome://global/content/xulBindings.xml#buttonleft");
      min-width           : 0px;
      margin              : 0px;
      border              : 1px solid transparent;
      color               : WindowText;
      -moz-user-focus     : ignore;
    }
    
  .button-toolbar-4 > .button-internal-box
    {
      padding             : 0px;
      border              : 1px solid transparent;
      vertical-align      : middle;
      text-align          : center;
    }
  
  .button-toolbar-4:hover
    {
      border              : 1px solid ThreeDDarkShadow;
      color               : #0000FF;
    } 
    
  .button-toolbar-4[disabled="true"],
  .button-toolbar-4[disabled="true"]:hover,
  .button-toolbar-4[disabled="true"]:hover:active
    {
      border              : 1px solid transparent;
      color               : GrayText;
    }
    
  .button-toolbar-4:hover > .button-internal-box
    {
      border-left         : 1px solid ThreeDHighlight;
      border-top          : 1px solid ThreeDHighlight;
      border-right        : 1px solid ThreeDShadow;
      border-bottom       : 1px solid ThreeDShadow;
    }

  .button-toolbar-4:hover:active > .button-internal-box
    {
      padding             : 0px;
      border-left         : 1px solid ThreeDShadow !important;
      border-top          : 1px solid ThreeDShadow !important;
      border-right        : 1px solid ThreeDHighlight !important;
      border-bottom       : 1px solid ThreeDHighlight !important;
    }

  .button-toolbar-4 > .button-internal-box > .button-text-container
    {
      text-align          : center;
    }
    
  .button-toolbar-4[disabled="true"] > .button-internal-box,
  .button-toolbar-4[disabled="true"]:hover > .button-internal-box,
  .button-toolbar-4[disabled="true"]:hover:active > .button-internal-box
    {
      padding             : 0px !important;
      border              : 1px solid transparent !important;
    }

  menubutton.button-toolbar-4
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-single-right");
    }

/** Low profile rollover buttons, e.g. "search"
 **/  
 
  .button-toolbar-3
    {
      -moz-binding          : url("chrome://global/content/xulBindings.xml#buttonleft");
      margin                : 0px 0px 1px 3px !important;
      min-width             : 0px;
      background-color      : transparent;
      color                 : WindowText;
      -moz-user-focus       : ignore;
    }  
    
  .button-toolbar-3 > .button-internal-box
    {
      background-color      : ThreeDFace;
    }
    
  .button-toolbar-3, 
  .button-toolbar-3[disabled="true"]:hover,
  .button-toolbar-3[disabled="true"]:hover:active
    {
      border                : 1px solid transparent;
    }
    
  .button-toolbar-3:hover, .button-toolbar-3:hover:active
    {
      border-color          : ThreeDDarkShadow;
    }
    
  .button-toolbar-3 > .button-internal-box,
  .button-toolbar-3[disabled="true"] > .button-internal-box,
  .button-toolbar-3[disabled="true"]:hover > .button-internal-box,
  .button-toolbar-3[disabled="true"]:hover:active > .button-internal-box
    {
      border-left           : 1px solid ThreeDHighlight !important;
      border-top            : 1px solid ThreeDHighlight !important;
      border-right          : 1px solid ThreeDShadow !important;
      border-bottom         : 1px solid ThreeDShadow !important;
      padding               : 1px 4px 1px 4px;
    }
    
  .button-toolbar-3:hover:active > .button-internal-box 
    {
      border-left           : 1px solid ThreeDShadow !important;
      border-top            : 1px solid ThreeDShadow !important;
      border-bottom         : 1px solid ThreeDHighlight !important;
      border-right          : 1px solid ThreeDHighlight !important;
      padding               : 2px 3px 0px 5px;
    } 

  .button-toolbar-3 > .button-internal-box > .button-icon,
  .button-toolbar-3 > .button-internal-box > .button-text
    {
      margin-right          : 2px;
    }  

/** Expanding Region Button **/

/* outer frame */
  .button-expander
    {
      border              : none;
      padding             : 0;
      margin              : 1px 5px 3px 1px;
      background-color    : inherit;
      list-style-image    : url("chrome://global/skin/closedtwisty.gif");
      color               : #0000FF;
      text-decoration     : underline;
    }
    
  .button-expander[open="true"]
    {
      list-style-image    : url("chrome://global/skin/opentwisty.gif");
    }
    
  .button-expander > .button-internal-box
    {
      border              : none;
      background-color    : inherit;
      padding             : 0;
      margin              : 0;
    }

  .button-expander:hover 
    {
      color               : #FF0000;
    }


