@import url(chrome://messenger/skin/messenger.css);

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to HTML */
@namespace html url("http://www.w3.org/1999/xhtml"); /* namespace for HTML elements */

spring.spacer {
	width: 5px;
	height: 5px;
}

box.cleanborder {
	margin: 10px;
	padding: 10px;
	border: 2px groove white;
	width: 100%;
}

box.padded {
	margin: 10px;
	width: 100%;
}


/* addressing widget */

#addressingWidgetTree {
  height : 80px;
  width : 0px;
}  

tree[class="addressingWidget"] treeitem > treerow  > treecell > box > image {
	vertical-align: middle;
	padding:2px;
	border:none;
	list-style-image: url("chrome://messenger/skin/addressbook/person.gif");
	-moz-user-focus: ignore;
}

/*
menulist.outset
{
    padding             : 0px;
    border              : 1px solid #000000;
    background-color    : #CCCCCC;
    -moz-border-radius  : 3px 2px 2px 3px;
    margin              : 1px;
}

menulist.outset > menupopup > menuitem
{
  max-width: auto;
  min-width: 32px;
}

menulist.outset > .menu-text 
{
    border              : 1px outset #CCCCCC;;
    padding             : 1px 4px 2px 4px;
    margin-right        : 0px;
}
    
menulist.outset[open="true"] > .menu-text 
{
    border              : 1px inset #CCCCCC;;
    padding             : 2px 4px 1px 4px;
}
*/

textfield.addressingWidget[autocomplete="true"] {
    border              : 2px solid #FFFFFF;
    margin              : 1px;
}

textfield.addressingWidget[autocomplete="true"][focused="true"]
{
    border              : 2px solid #6699cc;
    margin              : 1px;
}

textfield.addressingWidget[autocomplete="true"] > box
{
    border              : none;
}

#button-send {
	list-style-image:url("chrome://messenger/skin/messengercompose/send.gif");
}

#button-address {
	list-style-image:url("chrome://messenger/skin/messengercompose/address.gif");
}

#button-attach {
	list-style-image:url("chrome://messenger/skin/messengercompose/attach.gif");
}

#button-quote {
	list-style-image:url("chrome://messenger/skin/messengercompose/quote.gif");
}

#button-spelling {
	list-style-image:url("chrome://messenger/skin/messengercompose/spelling.gif");
}

#button-save {
	list-style-image:url("chrome://messenger/skin/messengercompose/save.gif");
}

#button-stop {
	list-style-image:url("chrome://global/skin/stop.gif");
}

toolbar#MsgHeadersToolbar {
  border-bottom: 1px solid #999999;
}

box#addressingWidget {
  -moz-user-focus: normal;
}

tree#attachmentBucket {
  -moz-user-focus: normal;
}

#msgSubject {
  -moz-user-focus: normal;
}

#msgIdentity {
  -moz-user-focus: normal;
}

.identity-popup-item
{
  -moz-binding: url(chrome://messenger/content/messengercompose/mailComposeBindings.xml#fromMenuitem);
}

.composemenu-text-2
{
  color: gray;
  font-style: italic;
}

#askSendFormat {
	width: 40em;
}

#convertYes, #convertAltering, #convertNo {
	border: 1px solid black;
}

#convertYes {
	list-style-image:url("chrome://messenger/skin/messengercompose/sendConvYes.gif");
}

#convertAltering {
	list-style-image:url("chrome://messenger/skin/messengercompose/sendConvAltering.gif");
}

#convertNo {
	list-style-image:url("chrome://messenger/skin/messengercompose/sendConvNo.gif");
}

#convertDefault {
	border: 1px solid black;
	list-style-image:url("chrome://messenger/skin/messengercompose/sendConvYes.gif");
} /* Workaround for bug 50217. Please remove this rule, when this bug is fixed. */

#navprintplus {
	display:none !important; 
}
