/* stylesheet for XUL <checkbox> element */

/* default checkbox for dialogs */

/* outer checkbox frame */
  checkbox 
    {
      margin: 3px 5px 3px 5px;
    }

  checkbox > .internal-box
    {
      -moz-user-focus: none;
    }   

/* checkmark outer frame */
  checkbox > .internal-box > .checkmark-box 
    {
      border: 1px solid #000000;
      -moz-border-radius: 3px 2px 2px 3px;
      background-color: #CCCCCC;
      margin-top: 2px;
      margin-right: 4px;
    }

  checkbox[disabled="true"] > .internal-box > .checkmark-box,
  checkbox[disabled="true"]:hover > .internal-box > .checkmark-box 
    {
      border: 1px solid #999999;
    }
    
/* checkmark inner frame */
  checkbox > .internal-box > .checkmark-box > .checkbox-check 
    {
      border: 1px outset #CCCCCC;
      width: 10px;
      height: 10px;
      list-style-image: none;
    }
  
  checkbox[checked="true"] > .internal-box > .checkmark-box > .checkbox-check 
    {
      list-style-image: url(chrome://global/skin/check-check.gif);
    }
    
  checkbox[checked="true"][disabled="true"] > .internal-box > .checkmark-box > .checkbox-check
    {
      list-style-image: url(chrome://global/skin/check-check-disabled.gif);
    }  

  checkbox:hover:active > .internal-box > .checkmark-box > .checkbox-check 
    {
      border: 1px inset #CCCCCC;
    }
  
  checkbox[disabled="true"] > .internal-box > .checkmark-box > .checkbox-check,
  checkbox[disabled="true"]:active > .internal-box > .checkmark-box > .checkbox-check 
    {
      border: 1px outset #CCCCCC;
      -moz-border-radius: 0px;
    }

  checkbox > .internal-box > .checkbox-icon 
    {
      list-style-image: inherit;
    }
    
/* checkmark label/icon frame */
  checkbox[value] > .internal-box > html
    {
      margin: 0px 0px 0px 4px;
      padding: 1px;
    }

  checkbox[disabled="true"][value] > .internal-box > html 
    {
      color: #999999;
    }
    
  checkbox:focus > .internal-box > html 
    {
      border              : 1px dotted black;
      padding             : 0px;
    }
