/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 */

/* basic mail folders */
.tree-cell-folderpane-icon
{
 list-style-image: url("chrome://messenger/skin/folder-closed.gif");
}

treeitem.folderTreeItem[open="true"] > treerow > .tree-cell-folderpane-icon
{
 list-style-image: url("chrome://messenger/skin/folder-open.gif");
}

/* special folder */
.tree-cell-folderpane-icon[SpecialFolder="Inbox"]
{
 list-style-image: url("chrome://messenger/skin/folder-inbox.gif");
}

.tree-cell-folderpane-icon[SpecialFolder="Trash"]
{
 list-style-image: url("chrome://messenger/skin/folder-trash.gif");
}

.tree-cell-folderpane-icon[IsServer="true"]
{
 list-style-image: url("chrome://messenger/skin/server-mail.gif");
}

treeitem.folderTreeItem[open="true"] > treerow > .tree-cell-folderpane-icon[IsServer="true"]
{
 list-style-image: url("chrome://messenger/skin/server-mail.gif");
}

.tree-cell-folderpane-icon[BiffState="NewMail"][IsServer="true"]
{
 list-style-image: url("chrome://messenger/skin/server-mail-new.gif");
}

treeitem[open="true"] > treerow > .tree-cell-folderpane-icon[BiffState="NewMail"][IsServer="true"]
{
 list-style-image: url("chrome://messenger/skin/server-mail-new.gif");
}

/* differentiate new messages on inbox/folders from biff on the server */
.tree-cell-folderpane-icon[NewMessages="true"]
{
    list-style-image: url("chrome://messenger/skin/folder-new-closed.gif");
	font-weight: bold;
}

.tree-cell-folderpane-icon[SpecialFolder="Inbox"][NewMessages="true"]
{
 list-style-image: url("chrome://messenger/skin/folder-inbox-new.gif");
 font-weight: bold;
}

treeitem[open="true"] > treerow > .tree-cell-folderpane-icon[NewMessages="true"]
{
 list-style-image: url("chrome://messenger/skin/folder-new-open.gif");
 font-weight: bold;
}


/* IMAP folders */

.tree-cell-folderpane-icon[IsServer="true"][ServerType="imap"][IsSecure="true"]
{
    list-style-image: url("chrome://messenger/skin/server-remote-lock.gif");
}

treeitem.folderTreeItem[open="true"] > treerow > .tree-cell-folderpane-icon[IsServer="true"][ServerType="imap"][IsSecure="true"]
{
 list-style-image: url("chrome://messenger/skin/server-remote-lock.gif");
}

/* Local servers */
.tree-cell-folderpane-icon[IsServer="true"][ServerType="none"] 
{
 list-style-image: url("chrome://messenger/skin/server-local.gif");
}

treeitem.folderTreeItem[open="true"] > treerow > .tree-cell-folderpane-icon[IsServer="true"][ServerType="none"]
{
 list-style-image: url("chrome://messenger/skin/server-local.gif");
}


/* News folders */
.tree-cell-folderpane-icon[ServerType="nntp"]
{
    list-style-image: url("chrome://messenger/skin/folder-newsgroup.gif");
}

.tree-cell-folderpane-icon[IsServer="true"][ServerType="nntp"][IsSecure="true"]
{
    list-style-image: url("chrome://messenger/skin/server-news-lock.gif");
}

treeitem.folderTreeItem[open="true"] > treerow > .tree-cell-folderpane-icon[IsServer="true"][ServerType="nntp"][IsSecure="true"]
{
 list-style-image: url("chrome://messenger/skin/server-news-lock.gif");
}

.tree-cell-folderpane-icon[IsServer="true"][ServerType="nntp"] 
{
    list-style-image: url("chrome://messenger/skin/server-news.gif");
}

treeitem.folderTreeItem[open="true"] > treerow > .tree-cell-folderpane-icon[IsServer="true"][ServerType="nntp"]
{
 list-style-image: url("chrome://messenger/skin/server-news.gif");
}

/*All Servers*/
.tree-folder-row[IsServer="true"]
{
	font-weight: bold;
}

.tree-folder-row[HasUnreadMessages="true"]
{
	font-weight: bold;
}

.tree-folder-row[NoSelect="true"]
{
    color: gray;
    font-style: italic;
}

#folder-panel {
	min-width: 10px;
}

treeitem[empty="true"] > treerow > treecell > .tree-cell-twisty {               
  visibility:hidden;
}
