/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 */

@import url(chrome://communicator/skin/);

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to HTML */
@namespace html url("http://www.w3.org/1999/xhtml"); /* namespace for HTML elements */

spring.spacer {
	width: 5px;
	height: 5px;
}

box.cleanborder {
	margin: 10px;
	padding: 10px;
	border: 2px groove white;
	width: 100%;
}

box.padded {
	margin: 10px;
	width: 100%;
}

/* Header toolbar */

/* Text labels only for this window */

.label {
	color: #FFFFFF;
}


/* addressing widget */

#addressingWidgetTree {
  height: 80px;
  width: 0px;
  border: 1px inset #5B7693;
  -moz-user-focus: none;
}  

#listcol-addressingWidget {
  width: 9em;
  border-right: 1px solid #D3D3E5;
}

#addressingWidgetTree > treechildren > treeitem > treerow,
#addressingWidgetTree > treechildren > treeitem[selected="true"] > treerow {
  border: none;
  background-color: inherit;
  color: inherit;
}

.treecell-addressingWidget {
	vertical-align: middle;
  padding: 0px;
  border-bottom: 1px solid #D3D3E5;
}

.treecell-addressingWidget:first-child {
  border-top: none;
  border-bottom: none;
}

.dummy-row-cell:first-child {
  border-top: none;
  border-bottom: 1px solid #D3D3E5;
}

.aw-menulist {
  margin: 0px;
  border-top: none;
  border-left: none;
  border-color: #314152;
}

.person-icon {
  margin : 2px 4px 2px 4px;
	border: none;
	list-style-image: url("chrome://messenger/skin/addressbook/person.gif");
	-moz-user-focus: ignore;
}

/*
menulist.outset
{
    padding             : 0px;
    border              : 1px solid #000000;
    background-color    : #CCCCCC;
    -moz-border-radius  : 3px 2px 2px 3px;
    margin              : 1px;
}

menulist.outset > menupopup > menuitem
{
  max-width: auto;
  min-width: 32px;
}

menulist.outset > .menu-text 
{
    border              : 1px outset #CCCCCC;;
    padding             : 1px 4px 2px 4px;
    margin-right        : 0px;
}
    
menulist.outset[open="true"] > .menu-text 
{
    border              : 1px inset #CCCCCC;;
    padding             : 2px 4px 1px 4px;
}
*/

textfield.addressingWidget[autocomplete="true"] {
    border              : 2px solid #FFFFFF;
    margin              : 1px;
}

textfield.addressingWidget[autocomplete="true"][focused="true"]
{
    border              : 2px solid #6699cc;
    margin              : 1px;
}

textfield.addressingWidget[autocomplete="true"] > box
{
    border              : none;
}

#button-send, #button-address, #button-attach, #button-quote, #button-spelling, #button-save, #button-stop
  {
  	min-width			: 48px;
  }

#button-send {
	list-style-image:url("chrome://messenger/skin/messengercompose/send.gif");
}

#button-send[disabled="true"],
#button-send[disabled="true"]:hover,
#button-send[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/send-disabled.gif");
  } 

#button-send:hover
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/send-hover.gif");
  } 

#button-send:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/send-clicked.gif");
  } 

#button-address {
	list-style-image	  : url("chrome://messenger/skin/messengercompose/address.gif");
}

#button-address[disabled="true"],
#button-address[disabled="true"]:hover,
#button-address[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/address-disabled.gif");
  } 

#button-address:hover
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/address-hover.gif");
  } 

#button-address:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/address-clicked.gif");
  } 

#button-attach {
	list-style-image	  : url("chrome://messenger/skin/messengercompose/attach.gif");
}

#button-attach[disabled="true"],
#button-attach[disabled="true"]:hover,
#button-attach[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/attach-disabled.gif");
  } 

#button-attach:hover
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/attach-hover.gif");
  } 

#button-attach:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/attach-clicked.gif");
  } 

#button-quote {
	list-style-image	  : url("chrome://messenger/skin/messengercompose/quote.gif");
}

#button-quote[disabled="true"],
#button-quote[disabled="true"]:hover,
#button-quote[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/quote-disabled.gif");
  } 

#button-quote:hover
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/quote-hover.gif");
  } 

#button-quote:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/quote-clicked.gif");
  } 

#button-spelling {
	list-style-image:url("chrome://messenger/skin/messengercompose/spelling.gif");
}

#button-spelling[disabled="true"],
#button-spelling[disabled="true"]:hover,
#button-spelling[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/spelling-disabled.gif");
  } 

#button-spelling:hover
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/spelling-hover.gif");
  } 

#button-spelling:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/spelling-clicked.gif");
  }

#button-save {
	list-style-image:url("chrome://messenger/skin/messengercompose/save.gif");
}

#button-save[disabled="true"],
#button-save[disabled="true"]:hover,
#button-save[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/save-disabled.gif");
  } 

#button-save:hover
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/save-hover.gif");
  } 

#button-save:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/messengercompose/save-clicked.gif");
  } 

#button-stop {
	list-style-image:url("chrome://global/skin/stop.gif");
}

#button-stop[disabled="true"],
#button-stop[disabled="true"]:hover,
#button-stop[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://global/skin/stop-disabled.gif");
  } 

#button-stop:hover
  {
    list-style-image      : url("chrome://global/skin/stop-hover.gif");
  } 

#button-stop:hover:active
  {
    list-style-image      : url("chrome://global/skin/stop-clicked.gif");
  }

box#addressingWidget {
  -moz-user-focus: normal;
}

tree#attachmentBucket {
  -moz-user-focus: normal;
}

#msgSubject {
  -moz-user-focus: normal;
}

#msgIdentity {
  -moz-user-focus: normal;
}

.identity-popup-item
{
  -moz-binding: url(chrome://messenger/content/messengercompose/mailComposeBindings.xml#fromMenuitem);
}

.composemenu-text-2
{
  color: gray;
  font-style: italic;
}


/* askSendFormat dialog */

#askSendFormat {
	width: 40em;
}

#askImageBox {
        vertical-align: top;
}

#convertYes {
	list-style-image:url("chrome://global/skin/question-icon.gif");
}

#convertAltering {
	list-style-image:url("chrome://global/skin/question-icon.gif");
}

#convertNo {
	list-style-image:url("chrome://global/skin/alert-icon.gif");
}

#convertDefault {
	list-style-image:url("chrome://global/skin/question-icon.gif");
} /* Workaround for bug 50217. Please remove this rule, when this bug is fixed. */

#compose-toolbar-sizer {
  border-top: none;
}

#navprintplus {
  display: none !important;                                                    
}
 
