/* 
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *  
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *  
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 */

/* This contains CSS just for editor toolbars */

@import url("chrome://editor/skin/EditModeTabs.css");

#EditorToolbox 
  {
    min-width             : 1px;
  }

#EditModeToolbar 
  {
    padding               : 0px;
    vertical-align: top;
    border-bottom         : 1px solid darkgray;
    margin-bottom         : 0px;
    min-width             : 1px;
    color                 : white;
    background-color      : ThreeDFace;
    overflow              : hidden;
  }

#EditModeToolbar > .toolbar-holder 
  {
    border-top: none;
    padding-bottom: 2px;
  }
  
#EditModeToolbar > toolbargrippy 
  {
    display: none;
  }
  
#EditModeLabel 
  {
    display: none;
  }

button.edit-mode:hover, 
button.edit-mode:hover:active,
button.edit-mode 
  {
    -moz-binding          : url(chrome://global/content/xulBindings.xml#buttonleft);
    -moz-border-radius    : 0px 0px 8px 8px;
    padding               : 1px 5px 1px 4px;
    margin                : 0px 1px;
    color                 : black;
    background-color      : #CCCCCC;
    border-top            : 0px;
    border-bottom         : 1px solid #666666;
    border-left           : 1px solid white;
    border-right          : 1px solid #666666;
  }

button.edit-mode:hover 
  {
    border                : 1px solid black;
    border-top            : 0px;
  }

button.edit-mode:hover:active 
  {
    padding               : 2px 4px 0px 5px;
  }

button.edit-mode[selected="1"] 
  {
    background-color      : #FFFFFF;
  }

button.edit-mode[selected="1"]:active,
button.edit-mode[selected="1"]:hover:active 
  {
    padding               : 2px 4px 0px 5px;
  }

#NormalModeButton 
  {
    list-style-image      : url(chrome://editor/skin/images/editmode-normal.gif); 
  }

#TagModeButton 
  {
    list-style-image      : url(chrome://editor/skin/images/editmode-tags.gif); 
  }

#SourceModeButton 
  {
    list-style-image      : url(chrome://editor/skin/images/editmode-html.gif); 
  }

#PreviewModeButton 
  {
    list-style-image      : url(chrome://editor/skin/images/editmode-preview.gif); 
  }

/* Image URLs for all Editor toolbar buttons */

#boldButton 
  {
    list-style-image      : url(chrome://editor/skin/images/bold.gif); 
  }

#boldButton[disabled="true"],
#boldButton[disabled="true"]:hover,
#boldButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/bold-disabled.gif");
  } 

#boldButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/bold-hover.gif");
  } 

#boldButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/bold-hover-active.gif");
  } 

#italicButton
  {
    list-style-image      : url("chrome://editor/skin/images/italic.gif");
  } 

#italicButton[disabled="true"],
#italicButton[disabled="true"]:hover,
#italicButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/italic-disabled.gif");
  } 

#italicButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/italic-hover.gif");
  } 

#italicButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/italic-hover-active.gif");
  } 

#underlineButton
  {
	  list-style-image      : url("chrome://editor/skin/images/underline.gif");
  } 

#underlineButton[disabled="true"],
#underlineButton[disabled="true"]:hover,
#underlineButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/underline-disabled.gif");
  } 

#underlineButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/underline-hover.gif");
  } 

#underlineButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/underline-hover-active.gif");
  } 

#newButton 
  {
    list-style-image      : url("chrome://editor/skin/images/newfile.gif");
  } 

#newButton[disabled="true"],
#newButton[disabled="true"]:hover,
#newButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/newfile-disabled.gif");
  } 

#newButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/newfile-hover.gif");
  } 

#newButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/newfile-hover-active.gif");
  } 

#openButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/openfile.gif");
  } 

#openButton[disabled="true"],
#openButton[disabled="true"]:hover,
#openButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/openfile-disabled.gif");
  } 

#openButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/openfile-hover.gif");
  } 

#openButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/openfile-hover-active.gif");
  } 

#saveButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/savefile.gif");
  } 

#saveButton[disabled="true"],
#saveButton[disabled="true"]:hover,
#saveButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/savefile-disabled.gif");
  } 

#saveButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/savefile-hover.gif");
  } 

#saveButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/savefile-hover-active.gif");
  } 

#saveButton[dirty="true"] 
  {
	  list-style-image      : url("chrome://editor/skin/images/savefile.gif");
  } 

#saveButton[dirty="true"][disabled="true"],
#saveButton[dirty="true"][disabled="true"]:hover,
#saveButton[dirty="true"][disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/savefile-disabled.gif");
  } 

#saveButton[dirty="true"]:hover
  {
    list-style-image      : url("chrome://editor/skin/images/savefile-hover.gif");
  } 

#saveButton[dirty="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/savefile-hover-active.gif");
  } 

#publishButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/publish.gif");
  } 

#publishButton[disabled="true"],
#publishButton[disabled="true"]:hover,
#publishButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/publish-disabled.gif");
  } 

#publishButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/publish-hover.gif");
  } 

#publishButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/publish-hover-active.gif");
  }

#previewButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/preview.gif");
  } 

#previewButton[disabled="true"],
#previewButton[disabled="true"]:hover,
#previewButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/preview-disabled.gif");
  } 

#previewButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/preview-hover.gif");
  } 

#previewButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/preview-hover-active.gif");
  }

#printButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/print.gif");
  } 

#printButton[disabled="true"],
#printButton[disabled="true"]:hover,
#printButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/print-disabled.gif");
  } 

#printButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/print-hover.gif");
  } 

#printButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/print-hover-active.gif");
  }

#findButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/find.gif");
  } 

#findButton[disabled="true"],
#findButton[disabled="true"]:hover,
#findButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/find-disabled.gif");
  } 

#findButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/find-hover.gif");
  } 

#findButton:hover:active
  {
    list-style-image	  : url("chrome://editor/skin/images/find-hover-active.gif"); 
  }

#linkButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/link.gif");
  } 

#linkButton[disabled="true"],
#linkButton[disabled="true"]:hover,
#linkButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/link-disabled.gif");
  } 

#linkButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/link-hover.gif");
  } 

#linkButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/link-hover-active.gif"); 
  }

#imageButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/image.gif");
  } 

#imageButton[disabled="true"],
#imageButton[disabled="true"]:hover,
#imageButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/image-disabled.gif");
  } 

#imageButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/image-hover.gif");
  } 

#imageButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/image-hover-active.gif"); 
  }

#namedAnchorButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/anchor.gif");
  } 

#namedAnchorButton[disabled="true"],
#namedAnchorButton[disabled="true"]:hover,
#namedAnchorButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/anchor-disabled.gif");
  } 

#namedAnchorButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/anchor-hover.gif");
  } 

#namedAnchorButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/anchor-hover-active.gif"); 
  }

#hlineButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/hline.gif");
  } 

#hlineButton[disabled="true"],
#hlineButton[disabled="true"]:hover,
#hlineButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/hline-disabled.gif");
  } 

#hlineButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/hline-hover.gif");
  } 

#hlineButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/hline-hover-active.gif"); 
  }

#tableButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/table.gif");
  } 

#tableButton[disabled="true"],
#tableButton[disabled="true"]:hover,
#tableButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/table-disabled.gif");
  } 

#tableButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/table-hover.gif");
  } 

#tableButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/table-hover-active.gif"); 
  }

#spellingButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/spell.gif");
  } 

#spellingButton[disabled="true"],
#spellingButton[disabled="true"]:hover,
#spellingButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/spell-disabled.gif");
  } 

#spellingButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/spell-hover.gif");
  } 

#spellingButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/spell-hover-active.gif"); 
  }
  
#DecreaseFontSizeButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/dec-font-size.gif");
  } 

#DecreaseFontSizeButton[disabled="true"],
#DecreaseFontSizeButton[disabled="true"]:hover,
#DecreaseFontSizeButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/dec-font-size-disabled.gif");
  } 

#DecreaseFontSizeButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/dec-font-size-hover.gif");
  } 

#DecreaseFontSizeButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/dec-font-size-hover-active.gif"); 
  }
  
#IncreaseFontSizeButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/inc-font-size.gif");
  } 

#IncreaseFontSizeButton[disabled="true"],
#IncreaseFontSizeButton[disabled="true"]:hover,
#IncreaseFontSizeButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/inc-font-size-disabled.gif");
  } 

#IncreaseFontSizeButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/inc-font-size-hover.gif");
  } 

#IncreaseFontSizeButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/inc-font-size-hover-active.gif"); 
  }
  
#ulButton 
  {
	  list-style-image      :url("chrome://editor/skin/images/bullets.gif");
  }

#ulButton[disabled="true"],
#ulButton[disabled="true"]:hover,
#ulButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/bullets-disabled.gif");
  } 

#ulButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/bullets-hover.gif");
  } 

#ulButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/bullets-hover-active.gif"); 
  }

#olButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/numbers.gif");
  }

#olButton[disabled="true"],
#olButton[disabled="true"]:hover,
#olButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/numbers-disabled.gif");
  } 

#olButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/numbers-hover.gif");
  } 

#olButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/numbers-hover-active.gif"); 
  }

#outdentButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/outdent.gif");
  } 

#outdentButton[disabled="true"],
#outdentButton[disabled="true"]:hover,
#outdentButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/outdent-disabled.gif");
  } 

#outdentButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/outdent-hover.gif");
  } 

#outdentButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/outdent-hover-active.gif"); 
  }

#indentButton 
  {
	  list-style-image      : url("chrome://editor/skin/images/indent.gif");
  } 

#indentButton[disabled="true"],
#indentButton[disabled="true"]:hover,
#indentButton[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/indent-disabled.gif");
  } 

#indentButton:hover
  {
    list-style-image      : url("chrome://editor/skin/images/indent-hover.gif");
  } 

#indentButton:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/indent-hover-active.gif"); 
  }

#AlignPopupButton {
	list-style-image:url("chrome://editor/skin/images/align.gif");
}

#InsertPopupButton {
	list-style-image:url("chrome://editor/skin/images/object-popup.gif");
}

#text-align-left,
#align-left-button
  {
	  list-style-image      : url("chrome://editor/skin/images/left.gif");
  } 

#text-align-left[disabled="true"],
#text-align-left[disabled="true"]:hover,
#text-align-left[disabled="true"]:hover:active,
#align-left-button[disabled="true"],
#align-left-button[disabled="true"]:hover,
#align-left-button[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/left-disabled.gif");
  } 

#text-align-left:hover,
#align-left-button:hover
  {
    list-style-image      : url("chrome://editor/skin/images/left-hover.gif");
  } 

#text-align-left:hover:active,
#align-left-button:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/left-hover-active.gif"); 
  }

#text-align-center,
#align-center-button
  {
	  list-style-image      : url("chrome://editor/skin/images/center.gif");
  } 

#text-align-center[disabled="true"],
#text-align-center[disabled="true"]:hover,
#text-align-center[disabled="true"]:hover:active,
#align-center-button[disabled="true"],
#align-center-button[disabled="true"]:hover,
#align-center-button[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/center-disabled.gif");
  } 

#text-align-center:hover,
#align-center-button:hover
  {
    list-style-image      : url("chrome://editor/skin/images/center-hover.gif");
  } 

#text-align-center:hover:active,
#align-center-button:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/center-hover-active.gif"); 
  }

#text-align-right,
#align-right-button
  {
	  list-style-image      : url("chrome://editor/skin/images/right.gif");
  } 

#text-align-right[disabled="true"],
#text-align-right[disabled="true"]:hover,
#text-align-right[disabled="true"]:hover:active
#align-right-button[disabled="true"],
#align-right-button[disabled="true"]:hover,
#align-right-button[disabled="true"]:hover:active 
 {
    list-style-image      : url("chrome://editor/skin/images/right-disabled.gif");
  } 

#text-align-right:hover,
#align-right-button:hover
  {
    list-style-image      : url("chrome://editor/skin/images/right-hover.gif");
  } 

#text-align-right:hover:active,
#align-right-button:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/right-hover-active.gif"); 
  }

#text-align-justify, #align-justify-button
  {
	  list-style-image      : url("chrome://editor/skin/images/justify.gif");
  }

#text-align-justify[disabled="true"],
#text-align-justify[disabled="true"]:hover,
#text-align-justify[disabled="true"]:hover:active
#align-justify-button[disabled="true"],
#align-justify-button[disabled="true"]:hover,
#align-justify-button[disabled="true"]:hover:active 
 {
    list-style-image      : url("chrome://editor/skin/images/justify-disabled.gif");
  } 

#text-align-justify:hover,
#align-justify-button:hover
  {
    list-style-image      : url("chrome://editor/skin/images/justify-hover.gif");
  } 

#text-align-justify:hover:active,
#align-justify-button:hover:active
  {
    list-style-image      : url("chrome://editor/skin/images/justify-hover-active.gif"); 
  }

.ColorPickerLabel 
  {
    border                : 1px inset white;
    margin                : 0px;
    padding               : 2px;
    text-align            : center;
  }

.color-button 
  {
    border                : 1px inset #CCCCCC;
    padding               : 0px;
    width                 : 14px;
    height                : 12px;
    margin                : 2px;
  }

.color-button:hover 
  {
    border                : 1px solid #000000;
  }

#TextColorButton 
  {
    margin                : 2px 9px 9px 2px;
  }

#BackgroundColorButton 
  {
    margin                : 9px 2px 2px 9px;
  }
  
