tabcontrol {
  margin: 1px 5px 2px 5px;
}

/********** Tab widget *********/
tab { 
  border-top: 1px solid white;
  border-bottom: 1px solid #666666;
  border-left: 1px solid white;
  border-right: 1px solid #666666;
  color: black; 
  padding: 3px 5px 3px 5px;
}

/* when a tab is selected this is how it should look */
tab[selected="true"] {
	font-weight: bold;
}

tab:hover { 
  color: #003366;
  text-decoration: underline;
}

tab:hover:active { 
  border-top: 1px solid #666666;
  border-bottom: 1px solid white;
  border-left: 1px solid #666666;
  border-right: 1px solid white;
  text-decoration: none;
}

tabbox {
  padding: 0px 2px 0px 2px;
}

    /* top tabs */
tabcontrol[align="vertical"] tabbox[align="horizontal"] tab { 
  border-bottom: none;
  -moz-border-radius: 8px 8px 0px 0px;
  padding-bottom: 1px;
  margin: 1px 2px 1px 2px;
}

	/* bottom tabs */
tabcontrol[align="vertical"] tabpanel + tabbox[align="horizontal"] tab { 
  border-top: none;
  border-bottom: 1px solid #666666;
  border-left: 1px solid white;
  border-right: 1px solid #666666;
  -moz-border-radius: 0px 0px 8px 8px;
  padding: 1px 5px 3px 5px;
  margin: 1px 2px 1px 2px;
}

	/* left tabs */
tabcontrol[align="horizontal"] tabbox[align="vertical"] tab { 
  border-right: none;
  -moz-border-radius: 8px 0px 0px 8px;
  padding-right: 1px;
  margin: 2px 1px 2px 1px;
}

	/* right tabs */
tabcontrol[align="horizontal"] tabpanel + tabbox[align="vertical"]  tab { 
  border-top: 1px solid white;
  border-bottom: 1px solid #666666;
  border-left: none;
  border-right: 1px solid #666666;
  -moz-border-radius: 0px 8px 8px 0px;
  padding: 3px 5px 1px 5px;
  margin: 2px 1px 2px 1px;
}

tabcontrol { 
  border: none; 
}

/* border on bottom only, no padding (used in search) */
tabpanel.light {
  border: none;
  border-bottom: 1px outset #CCCCCC;
  padding: 0px;
}

tabpanel {
  border	 		: 1px outset #FFFFFF;
  padding			: 5px;
}

