/** this should only contain XUL dialog and document window widget defaults. Defaults for widgets of
    a particular application should be in that application's style sheet.
	For example style definitions for navigator can be found in navigator.css

   THIS FILE IS LOCKED DOWN.  YOU ARE NOT ALLOWED TO MODIFY IT WITHOUT FIRST HAVING YOUR
   CHANGES REVIEWED BY hyatt@netscape.com.
**/

/*@import url(chrome://global/content/content.css);*/

@namespace url(http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul); /* set default namespace to XUL */
@namespace html url("http://www.w3.org/1999/xhtml"); /* namespace for HTML elements */
@namespace xbl url("http://www.mozilla.org/xbl"); /* namespace for XBL elements */

* {
  display: block;
}

*, *[disabled="true"] {
  -moz-user-focus: ignore;
}

/**
 * Hide the content, but don't destroy the frames. 
 * DO NOT USE "_collapsed" IN YOUR XUL! 
 */
*[collapsed="true"], *[moz-collapsed="true"] {
  visibility: collapse;
}

/* this is unfortunate. should be display="none" */
*[hidden="true"] {
  display: none;
}

checkbox,radio,tree,outliner,menulist {
  -moz-user-focus: normal;
}

menupopup, popup, splitter {
  -moz-user-focus: ignore;
}

treechildren, treehead, treerows, outlinercol, outlinerrows, outlinerbody {
  -moz-user-focus: none;
}

/** 
 * All elements that have no visual representation
 */
commands, commandset, command {
	display: none;
}

xbl|children {
  display: none;
}

broadcasterset, broadcaster {
	display: none;
}

observes {
	display: none;
}

template {
	display: none;
}

data {
  display: none;
}

keyset, key {
  display: none;
}

/* templates */
rule, conditions, action, bindings, binding, content, member, triple 
  {
    display: none;
  }

/**********************************
 * Window
 **********************************/

window { 
  overflow: hidden;
}

/**********************************
 * XUL widgets
 **********************************/

/******** Browser, editor, iframe ********/

browser, editor, iframe {
  display: inline;
}

browser {
  -moz-binding: url(chrome://global/content/xulBindings.xml#browser);
}

editor {
  -moz-binding: url(chrome://global/content/xulBindings.xml#editor);
}

iframe {
  -moz-binding: url(chrome://global/content/xulBindings.xml#iframe);
}

/******** ScrollBox ********/

scrollbox {
  -moz-binding: url(chrome://global/content/xulBindings.xml#scrollbox);
}

.scrollbox-innerbox {
  text-align: inherit;
  vertical-align: inherit;
}


/******** ArrowScrollBox ******/

arrowscrollbox {
  -moz-binding: url(chrome://global/content/xulBindings.xml#arrowscrollbox);
}

/******** Box *******/

/******** TitledBox *******/

box.titledbox-title {
}

box.titledbox-body {
   vertical-align: inherit;
   text-align: inherit;
}

titledbox {
  -moz-binding: url(chrome://global/content/xulBindings.xml#titledbox);
}

titledbox[value] {
  -moz-binding: url(chrome://global/content/xulBindings.xml#titledboxvalue);
}

title {
  -moz-binding: url(chrome://global/content/xulBindings.xml#title);
}

/******* ToolBox & ToolBar *******/

toolbox 
  { 
    -moz-user-focus       : ignore;
    -moz-binding          : url(chrome://global/content/toolbarBindings.xml#toolbox);
  }
  
menubar
  {
    -moz-user-focus       : ignore;
    -moz-binding          : url(chrome://global/content/toolbarBindings.xml#menubar);
  }

toolbar
  {
    -moz-user-focus       : ignore;
    -moz-binding          : url(chrome://global/content/toolbarBindings.xml#toolbar);
  }

toolbargrippy 
  {
    -moz-binding          : url(chrome://global/content/toolbarBindings.xml#toolbargrippy);
  }

.toolbar-holder[collapsed="true"] 
  {
    visibility            : collapse;
  }

/********* XP Menus ***********/

menubar > menu 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menu-menubar");
  }

menubar > menu.menu-iconic 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menu-menubar-iconic");
  }

menu 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menu");
  }
  
menu.menu-iconic 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menu-iconic");
  }

menuitem 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menuitem");
  }

menuitem.menuitem-iconic 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menuitem-iconic");
  }

menuitem[type="checkbox"],
menuitem[type="radio"] 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menuitem-iconic");
  }

menulist > menupopup > menuitem 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#menuitem-iconic");
  }

menuitem.menuitem-non-iconic
  {
    -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-item");
  }

  
menupopup 
  {
    -moz-binding: url("chrome://global/content/xulBindings.xml#popups");
    display               : none;
  }

popup {
  -moz-binding: url("chrome://global/content/xulBindings.xml#popups");
  display: none;
}

popup.tooltip, .popup-infopopup {
  -moz-binding: url("chrome://global/content/xulBindings.xml#tooltips");
}

menupopup[menugenerated="true"] {
  display: block;
}

popup[menugenerated="true"] {
  display: block;
}

menupopup, popup {
  z-index: 2147483647; 
}

/******** Titled buttons **********/

/******** Outliner widget ******/

outliner {
 width: 10px;
 height: 10px;
 min-width: 0px;
 min-height: 0px;
 -moz-binding: url("chrome://global/content/outlinerBindings.xml#outliner");
}

outlinercol {
 width: 16px;
 min-width: 16px;
 -moz-binding: url("chrome://global/content/outlinerBindings.xml#outlinercol");
}

outlinerbody {
 -moz-binding: url("chrome://global/content/outlinerBindings.xml#outlinerbody");
}

outlinerrows {
 -moz-binding: url("chrome://global/content/outlinerBindings.xml#outlinerrows");
}

/******** Tree widget **********/

tree {
 width: 200px;
 height: 200px;
 min-width: 0px;
 min-height: 0px;
 -moz-binding: url("chrome://global/content/treeBindings.xml#tree");
}

treecol {
  min-width: 16px;
}

tree > treechildren {
 -moz-binding: url("chrome://global/content/treeBindings.xml#treerows");
 overflow: auto;
 min-height: 0px;
}

treeitem { 
 -moz-binding: url("chrome://global/content/treeBindings.xml#treeitem");
} 

treecell { 
 vertical-align: middle;
 -moz-binding: url("chrome://global/content/treeBindings.xml#treecell");
} 

.treecell-text { 
 -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-text");
} 

.treecell-indent {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-indented-leaf");
}

treeitem[container="true"] > treerow > .treecell-indent {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-indented-folder");
}

.treecell-iconic {
 -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-iconic");
}

/* Inline Editable Treecell */
.treecell-editable {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-inline-edit");
}

.treecell-indent.treecell-editable {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-indented-leaf-inline-edit");
}

treeitem[container="true"] > treerow > .treecell-indent.treecell-editable {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-indented-folder-inline-edit");
}

.treecell-image {
 -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-image");
}

.treecell-header, .treecell-inset-header {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-header");
}

.treecell-header-image {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-header-image");
}

.treecell-align-right {
  -moz-binding: url("chrome://global/content/treeBindings.xml#treecell-align-right");
}

treeitem > treechildren {
  display: none;
}

treeitem[open="true"] > treechildren {
  display: block;
}

treecol[hidden="true"] {
  display: block;
  visibility: collapse;
}

treecell[hidden="true"] {
  display: block;
  visibility: collapse;
}

/********** Tab widget *********/

tab {
  -moz-binding: url(chrome://global/content/tabBindings.xml#tab);
}

tabpanel {
  -moz-binding: url(chrome://global/content/tabBindings.xml#tabpanel);
}

tabcontrol {
  -moz-binding: url(chrome://global/content/tabBindings.xml#tabcontrol);
}

tabbox {
  -moz-binding: url(chrome://global/content/tabBindings.xml#tabbox);
}

:-moz-deck-hidden {
   visibility: hidden;
}

/********** checkbox **********/

checkbox {
  -moz-binding: url(chrome://global/content/xulBindings.xml#checkbox);
}

radio 
  {
    -moz-binding          : url(chrome://global/content/radioBindings.xml#radio);
    -moz-user-focus       : none;
  }

radiogroup 
  {
    -moz-binding          : url(chrome://global/content/radioBindings.xml#radiogroup);
    -moz-user-focus       : normal;
  }

button, button.left {
  /*-moz-user-focus: normal;*/
  -moz-binding: url(chrome://global/content/xulBindings.xml#buttonleft);
}

button.top {
  -moz-binding: url(chrome://global/content/xulBindings.xml#buttontop);
}

button.right {
  -moz-binding: url(chrome://global/content/xulBindings.xml#buttonright);
}

button.bottom {
  -moz-binding: url(chrome://global/content/xulBindings.xml#buttonbottom);
}

toolbarseparator, menuseparator, separator {
  -moz-binding: url(chrome://global/content/xulBindings.xml#separator);
}


/* appending to end so we don't make hyatt cry */
progressmeter {
  -moz-binding: url(chrome://global/content/xulBindings.xml#progressmeter);
}

textfield {
  -moz-binding: url(chrome://global/content/xulBindings.xml#textfield);
  -moz-user-select: text;
}

textfield[multiline="true"] {
  -moz-binding: url(chrome://global/content/xulBindings.xml#textarea);
}

text[for] {
  -moz-binding: url(chrome://global/content/xulBindings.xml#text-label);
}

text[editable="true"] {
  -moz-user-select: text;
}

text[editable="true"], text[editable="true"][mode="display"] {
  -moz-binding: url(chrome://global/content/xulBindings.xml#text-editable-display);
}

text[editable="true"][mode="edit"] {
  -moz-binding: url(chrome://global/content/xulBindings.xml#text-editable-edit);
}

textfield[autocomplete="true"] {
  -moz-binding: url(chrome://global/content/autocomplete.xml#autocomplete);
}

colorpicker {
  -moz-binding: url(chrome://global/content/colorpickerBindings.xml#colorpicker);
}

colorpicker[type="button"] {
  -moz-binding: url("chrome://global/content/colorpickerBindings.xml#colorpickerButton");
  -moz-user-focus: normal;
}

/** Buttons with Menus:
 *  - menulist
 *  - menulist[editable="true"] (combobox)
 *  - menubutton
 **/

  menulist 
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menulist");
    }
  
  menulist[editable="true"] 
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menulist-editable") !important;
      -moz-user-focus: ignore;
    }
  
  menubutton
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-single-left");
    }

  menubutton.right
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-single-right");
    }
    
  menubutton.top
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-single-top");
    }

  menubutton.bottom
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-single-bottom");
    }

  menubutton.menubutton-dual,
  menubutton.menubutton-dual.left
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-dual-left");
    }
      
  menubutton.menubutton-dual.top
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-dual-top");
    }
      
  menubutton.menubutton-dual.right
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-dual-right");
    }
      
  menubutton.menubutton-dual.bottom
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-dual-bottom");
    }
      
  menubutton.menubutton-icon 
    {
      -moz-binding          : url("chrome://global/content/menulistBindings.xml#menubutton-icon");
    } 
    
/** 
 * Scrollbar <content> styles
 **/    
 
slider 
  {
    -moz-binding: url("chrome://global/content/xulBindings.xml#slider");
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton 
  {
    display               : inline;
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbar[value="hidden"] 
  {
    visibility            : hidden;
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

thumb 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

thumb[disabled="true"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton:active 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton[type="decrement"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton[type="decrement"][disabled="true"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton[type="increment"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbarbutton[type="increment"][disabled="true"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbar[align="vertical"] scrollbarbutton[type="decrement"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbar[align="vertical"] scrollbarbutton[type="decrement"][disabled="true"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbar[align="vertical"] scrollbarbutton[type="increment"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

scrollbar[align="vertical"] scrollbarbutton[type="increment"][disabled="true"] 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

slider[align="vertical"] thumb:active 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

slider 
  {
    -moz-user-focus       : ignore;
    -moz-user-select      : none;
  }

/**
 * Status Bar 
 **/  
statusbar 
  { 
    -moz-user-focus       : ignore;
    -moz-binding          : url("chrome://global/content/xulBindings.xml#statusbar");
  }

statusbarpanel
  {
    -moz-user-focus       : ignore;
    -moz-binding          : url("chrome://global/content/xulBindings.xml#statusbar-panel");
  }

/**
 * AutoRepeater
 */
autorepeater 
  {
    -moz-user-focus       : ignore;
  }

autorepeatbutton.up 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#autorepeatbutton-up");  
  }

autorepeatbutton.down 
  {
    -moz-binding          : url("chrome://global/content/xulBindings.xml#autorepeatbutton-down");  
}

splitter.tree-splitter {
  width: 0px;
  max-width: 0px;
}

stringbundle 
  {
    -moz-binding          : url("chrome://global/content/stringbundleBindings.xml#stringbundle");
    visibility            : collapse;
  }

resizer[direction="right"]
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#r-resizer");
  }  

resizer[direction="bottom"]
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#b-resizer");
  }  
  
resizer[direction="bottomright"]
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#rb-resizer");  
  }  
  
titlebar
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#titlebar");  
  }  
  
popup[type="floater"]
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#floater-normal");
  }
  
popup[type="floater"][docked="left"]
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#floater-dock-left");
  }
  
button.popupClose
  {
    -moz-binding          : url("chrome://global/content/popupBindings.xml#close-button") !important;
  }  
  
stringbundleset
  {
    -moz-binding          : url("chrome://global/content/stringbundleBindings.xml#stringbundleset");
    visibility            : collapse;
  }
