/* colorpicker tiles */

.colorpickertile {
  width                 : 20px;
  height                : 20px;
  margin                : 1px;
  border-left           : 1px solid ThreeDShadow;
  border-top            : 1px solid ThreeDShadow;
  border-right          : 1px solid ThreeDHighlight;
  border-bottom         : 1px solid ThreeDHighlight;
}

.colorpickertile[hover="true"] {
  border                : 1px solid #FFFFFF;
}

.colorpickertile[selected="true"] {
  border                : 1px solid #000000;
}

/* colorpicker button */

colorpicker[type="button"] {
  width: 35px;
  height: 20px;
  border-left: 1px solid ThreeDHighlight;
  border-top: 1px solid ThreeDHighlight;
  border-right: 1px solid ThreeDDarkShadow;
  border-bottom: 1px solid ThreeDDarkShadow;
}

.colorpicker-button-internal-box {
  border-left: 1px solid transparent;
  border-top: 1px solid transparent;
  border-right: 1px solid ThreeDShadow;
  border-bottom: 1px solid ThreeDShadow;
  padding: 3px;
}

.colorpicker-button-colorbox {
  border: 1px solid #000000;
}

colorpicker[type="button"]:focus {
  border: 1px solid black;
}

colorpicker[type="button"]:focus > .colorpicker-button-internal-box {
  border-left: 1px solid ThreeDHighlight;
  border-top: 1px solid ThreeDHighlight;
}

colorpicker[type="button"][open="true"] {
  border: 1px solid black;
}

colorpicker[type="button"][open="true"] > .colorpicker-button-internal-box {
  border: 1px solid ThreeDShadow;
}
