/*
The contents of this file are subject to the Netscape Public
License Version 1.1 (the "License"); you may not use this file
except in compliance with the License. You may obtain a copy of
the License at http://www.mozilla.org/NPL/

Software distributed under the License is distributed on an "AS
IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
implied. See the License for the specific language governing
rights and limitations under the License.

The Original Code is Mozilla Communicator client code, released
March 31, 1998.

The Initial Developer of the Original Code is Netscape
Communications Corporation. Portions created by Netscape are
 Copyright (C) 1998-1999 Netscape Communications Corporation. All
Rights Reserved.
*/
 
@import url(chrome://communicator/skin/);

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to HTML */
@namespace html url("http://www.w3.org/1999/xhtml"); /* namespace for XUL elements */

/* CardView styles - used in the Card View Pane */

#CardViewOuterBox {
  border-left: 1px solid ThreeDShadow;
  border-top: 1px solid ThreeDShadow;
  border-bottom: 1px solid ThreeDHighlight;
  border-right: 1px solid ThreeDHighlight;
}

#CardViewBox {
	min-width: 150px;
  border-left: 1px solid ThreeDDarkShadow;
  border-top: 1px solid ThreeDDarkShadow;
  border-bottom: 1px solid ThreeDFace;
  border-right: 1px solid ThreeDFace;
	background-color: #FFFFFF;
	overflow: auto;
	-moz-user-focus: ignore;
}

#CardViewInnerBox {
	margin-top: 2px;
	margin-bottom: 2px;
	padding-left: 8px;
	padding-right: 8px;
}

#CardTitle {
	font-size: 150%;
	font-weight: bold;
	border-bottom: 2px solid black;
	min-width: 120px;
	margin: 0px;
}
 
.cardViewGroup {
	margin-top: 8px;
	padding-bottom: 5px;
	min-width: 50px;
}

[class="CardViewHeading"] {
	padding: 1px;
	padding-left: 5px;
	margin: 0px 0px 1px 0px;
	background-color: #CCCCFF;
	color: black;
	font-weight: bold;
	min-width: 30px;
}

[class="CardViewText"] {
	padding-left: 20px;
	padding-right: 2px;
	min-width: 30px;
	margin: 0px;
}

html|a {
	padding-left: 0px;
	padding-right: 2px;
	border: none !important;
}

html|p {
    border: none !important;
}

[hide] {
  visibility: collapse;
}

/* CardEdit styles - used in the Card Edit Dialog */

[class="CardEditWidth"] {
	width: 25em;
}

[class="CardEditLabel"] {
	padding: 0px;
	margin-top: 3px;
}

[class="alignBoxWithFieldset"] {
	margin-left: 6px;
	margin-right: 5px;
}

.stateZipSpacer { width: 3em; }


/* Custom Trees */

tree[class="abDirectory"] treeitem > treerow > treecell > .tree-cell-primary-icon {
	list-style-image: url("chrome://messenger/skin/addressbook/myaddrbk.gif");
  margin-right: 1px;
  margin-left: 1px;
}

tree[class="abResults"] treeitem > treerow > treecell.cardicon {
	list-style-image: url("chrome://messenger/skin/abcard.gif");
	height: 14px;
	min-height: 14px;
  margin-right: 1px;
}

treeitem[empty="true"] > treerow > treecell > .tree-cell-twisty {               
  list-style-image: none !important;
  padding-left: 12px;
}

/* Toolbar buttons */

#button-newcard {
	list-style-image:url("chrome://messenger/skin/addressbook/newcard.gif");
}

#button-newcard[disabled="true"],
#button-newcard[disabled="true"]:hover,
#button-newcard[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newcard-disabled.gif");
  } 

#button-newcard:hover
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newcard-hover.gif");
  } 

#button-newcard:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newcard-hover-active.gif");
  } 

#button-newlist {
	list-style-image: url("chrome://messenger/skin/addressbook/newlist.gif");
}

#button-newlist[disabled="true"],
#button-newlist[disabled="true"]:hover,
#button-newlist[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newlist-disabled.gif");
  } 

#button-newlist:hover
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newlist-hover.gif");
  } 

#button-newlist:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newlist-hover-active.gif");
  } 

#button-editcard {
	list-style-image:url("chrome://messenger/skin/addressbook/person.gif");
}

#button-editcard[disabled="true"],
#button-editcard[disabled="true"]:hover,
#button-editcard[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/person-disabled.gif");
  } 

#button-editcard:hover
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/person-hover.gif");
  } 

#button-editcard:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/person-hover-active.gif");
  } 

#button-newmessage {
	list-style-image:url("chrome://messenger/skin/addressbook/newmsg.gif");
}

#button-newmessage[disabled="true"],
#button-newmessage[disabled="true"]:hover,
#button-newmessage[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newmsg-disabled.gif");
  } 

#button-newmessage:hover
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newmsg-hover.gif");
  } 

#button-newmessage:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/newmsg-hover-active.gif");
  }

#button-delete {
	list-style-image:url("chrome://messenger/skin/addressbook/trash.gif");
}

#button-delete[disabled="true"],
#button-delete[disabled="true"]:hover,
#button-delete[disabled="true"]:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/trash-disabled.gif");
  } 

#button-delete:hover
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/trash-hover.gif");
  } 

#button-delete:hover:active
  {
    list-style-image      : url("chrome://messenger/skin/addressbook/trash-hover-active.gif");
  } 
  
  

/* ==FOR abSelectAddressesDialog.xul =======*/

#3PaneBox {
}

#dirTreeBox {
	width			            : 180px;
	height			          : 100%; 
	background-color      : window;
  border-left           : 1px solid ThreeDShadow;
  border-top           : 1px solid ThreeDShadow;
  border-right          : 1px solid ThreeDHighlight;
  border-bottom         : 1px solid ThreeDHighlight;
}

/* -note- #dirTree#resultsTree is shared with addressbook.xul */

#sidebar-box {
  border: none;
  border-left: 1px solid ThreeDShadow;
  border-right: 1px solid ThreeDHighlight;
}

tree > treehead > treerow {
  border: none;
}

#dirTree { // Tree that lists different Address Books
  min-width		   : 10px;
  border-top     : none;
  border-left    : none;
  border-right   : none;
}

#dirTreeBox {
  border-left       : 1px solid ThreeDShadow;
  border-right      : 1px solid ThreeDHighlight;
  border-bottom     : none;
}

#dirTree[type="dialog"] {
}

#resultsTree {
  border-top        : none;
  border-bottom     : none;
}
 
#results-bucket-tree-box {
}

#resultsTreeBox {
	background-color: window;
  border-top: 1px solid ThreeDShadow;
}

#vertical-splitter {
  min-width     : 4px;
}

#addToBucketButtonBox { // Row of "To" "CC" and "Bcc" buttons
	padding			: 0.3em; 
	min-width		: 10px;
  border-top: 1px solid ThreeDHighlight;
}

#bucketBox {
	height			: 170px;
}

#addressBucket {
	height			: 100px; 
	min-width		: 10px;
}

#rightColumnButtonBox { // Column with "New", "Edit" and "Remove" buttons
	padding			: .5em; 
	padding-right	: 0px;
}

.3rd-column-spring {  // Vertical Springs between 3rd column buttons
	height			: 10px;
}

.middle-button-spring { // Springs between To, CC, and BCC buttons
	width			: 10px;
}

#bucket-splitter {
  border: none;
  min-height: 4px;
}

#sidebar-panels-splitter {
    border-top            : none;
}


