/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributors:
 *   Ben Goodger <ben@netscape.com>
 *   Chris Nelson <chrisn@statecollege.com>
 *
 */

@import url(chrome://global/skin/global.css);

window.dialog {
  padding: none;
}

.dimmed-highcontrast {
  color: #99cccc ! important;
} 

#profiles > treechildren > treeitem > treerow > treecell > .tree-cell-icon {
  list-style-image: url("chrome://communicator/skin/profile/profileicon-large.gif");
}

#profiles > treechildren > treeitem > treerow > treecell[rowMigrate="no"] > .tree-cell-icon {
  list-style-image: url("chrome://communicator/skin/profile/migrate.gif");
}

/* profile selection dialog */
html#intro {
  width: 17em;
}

box#managebuttons > button {
  min-width: 8em;
}

/* display area */
box#contentarea {
  border-top: 2px groove #CCCCCC;
  border-bottom: 2px groove #CCCCCC;
  padding: 7px;
}

/* top border on status area */
box#wizardButtons {
  padding-top: 1px;
  padding-bottom: 1px;
}

box.selection {
  margin-top: 4px;
}
