/** 
 * styles for search widgets used by Mail Filter dialog and Search
 * and hopefully one day Bookmarks/History...
 **/

.search-menulist, .search-value-menulist, .search-value-textfield
  {
    margin                : 0px;
  }