/* 
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *  
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *  
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 */

/* This contains CSS just for smiley menu */

#smileButton {
  list-style-image:url("chrome://editor/content/images/smile.gif"); 
}

menu:hover > #smileButton, 
menu:hover:active > #smileButton[toggled="true"] {
	list-style-image:url("chrome://editor/content/images/smile_hover.gif");
}

menu:hover:active > #smileButton,
menu:hover > #smileButton[toggled="true"] {
	list-style-image:url("chrome://editor/content/images/smile_active.gif");
}

#smileButton[disabled="true"], 
menu:hover > #smileButton[disabled="true"], 
menu:hover:active > #smileButton[disabled="true"] {
	list-style-image:url("chrome://editor/content/images/smile_disabled.gif");
}


#insert-smile {

   list-style-image:url(chrome://editor/content/images/smile.gif);
}

#insert-frown {
   list-style-image:url(chrome://editor/content/images/frown.gif);
}

#insert-wink {
   list-style-image:url(chrome://editor/content/images/wink.gif);
}

#insert-sick {
   list-style-image:url(chrome://editor/content/images/sick.gif);
}

#insert-smile5 {
   list-style-image:url(chrome://editor/content/images/smile.gif);
}

#insert-smile6 {
   list-style-image:url(chrome://editor/content/images/frown.gif);
}

#insert-smile7 {
   list-style-image:url(chrome://editor/content/images/wink.gif);
}



