/* stylesheet for XUL <checkbox> element */

/* default checkbox for dialogs */

/* outer checkbox frame */
  checkbox 
    {
      border        : 2px solid transparent;
      margin			  : 0px 2px 0px 2px;
      padding-left  : 1px;
      padding-right : 1px;
    }

  checkbox > .internal-box
    {
      -moz-user-focus: none;
    }   

/* checkmark outer frame */
  checkbox > .internal-box > .checkmark-box 
    {
	  margin: 3px 2px 3px 3px;
    }

/* checkmark inner frame */
  checkbox > .internal-box > .checkmark-box > .checkbox-check 
    {
      list-style-image: url(chrome://global/skin/check-cb.gif);
      
    }
  
  checkbox[checked="true"] > .internal-box > .checkmark-box > .checkbox-check 
    {
      list-style-image: url(chrome://global/skin/check-cb-check.gif);
    }
    
  checkbox[checked="true"][disabled="true"] > .internal-box > .checkmark-box > .checkbox-check,
  checkbox[checked="true"][disabled="true"]:hover:active > .internal-box > .checkmark-box > .checkbox-check
    {
      list-style-image: url(chrome://global/skin/check-cb-check-disabled.gif);
    }  

  checkbox:hover:active > .internal-box > .checkmark-box > .checkbox-check 
    {
      list-style-image: url(chrome://global/skin/check-cb-pressed.gif);  
    }
  
  checkbox[disabled="true"] > .internal-box > .checkmark-box > .checkbox-check,
  checkbox[disabled="true"]:hover:active > .internal-box > .checkmark-box > .checkbox-check
    {
  	  list-style-image: url(chrome://global/skin/check-cb-disabled.gif);  
    }

  checkbox[checked="true"]:hover:active > .internal-box > .checkmark-box > .checkbox-check 
    {
      list-style-image: url(chrome://global/skin/check-cb-check-pressed.gif);
    }

  checkbox > .internal-box > .checkbox-icon 
    {
      list-style-image: inherit;
    }
    
/* checkmark label/icon frame */
  checkbox[value] > .internal-box > html
    {
      margin: 0px 0px 2px 0px;
      padding: 1px;
    }

  checkbox[disabled="true"][value] > .internal-box > html,
  checkbox[disabled="true"][value]:hover:active > .internal-box > html
    {
      color: #999999;
    }
    
  checkbox:focus
    {
      border-color        : #8C9EB5;
      -moz-border-radius  : 4px 5px 4px 5px;
    }
