 
/******* ToolBox & ToolBar *******/

toolbar
  {
    background-color      : #CCCCCC;
    border-bottom         : 1px solid #003366;
  }

toolbargrippy 
  { 
    background-image      : url("chrome://global/skin/taskbar-tab-trans.gif"); 
    background-repeat     : no-repeat;
    border-right          : 1px solid #003366;
    width                 : 10px;
    height                : 10px;
  } 

toolbar[collapsed="true"]
  {
    min-height            : 0px;
  }

toolbar[collapsed="true"] > toolbargrippy 
  {
    width                 : 30px;
  }

toolbargrippy:hover 
  {
    background-color      : #99cccc !important; 
    background-image      : url("chrome://global/skin/taskbar-tab-hover.gif") !important;  
  } 

  
.toolbar-primary 
  {
    background-image      : url("chrome://global/skin/navbar-bg.gif");
    background-color      : #CCCCCC;
    padding               : 0px;
    border                : none;
  }
  
.toolbar-primary > toolbargrippy, .toolbar-standard > toolbargrippy
  {
    background-color      : #003366; 
    background-image      : url("chrome://global/skin/taskbar-tab.gif"); 
    background-repeat     : no-repeat;
  }
  
.toolbar-standard 
  {
    color                 : white;
    background-color      : #003366;
    padding               : 0px;
    margin                : 0px;
    border                : none;
  }


.toolbarseparator-standard
  { 
    width                 : 1px;
    border-left           : 1px solid #9D9D9D;
    border-right          : 1px solid #FFFFFF;
    margin                : 2px 0.2em 2px 0.2em;
  } 
