@namespace url(http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul); /* set default namespace to XUL */

/********* XP Scrollbar *********/

scrollbar 
  {
    -moz-binding          : url("chrome://global/skin/classicBindings.xml#scrollbar");
  }

/********* XP Scrollbar *********/

thumb 
  {
    -moz-binding          : url(chrome://global/skin/classicBindings.xml#thumb);
    border-left           : 1px solid ThreeDLightShadow;
    border-top            : 1px solid ThreeDLightShadow;
    border-right          : 1px solid ThreeDDarkShadow;
    border-bottom         : 1px solid ThreeDDarkShadow;
    background-color      : ThreeDFace;
  }

.thumb-box
  {
    border-left           : 1px solid ThreeDHighlight;
    border-top            : 1px solid ThreeDHighlight;
    border-right          : 1px solid ThreeDShadow;
    border-bottom         : 1px solid ThreeDShadow;
  }
  
.thumb-spring
  {
  	min-width			  : 4px;
  	min-height			  : 4px;
  } 
  
/**
 * Scrollbar button
 **/  
scrollbarbutton 
  {
    -moz-binding          : url("chrome://global/skin/classicBindings.xml#scrollbarbutton");
    cursor                : default;
    border-left           : 1px solid ThreeDLightShadow;
    border-top            : 1px solid ThreeDLightShadow;
    border-right          : 1px solid ThreeDDarkShadow;
    border-bottom         : 1px solid ThreeDDarkShadow;
    background-color      : ThreeDFace;
  }

.scrollbarbutton-box
  {
    border-left           : 1px solid ThreeDHighlight;
    border-top            : 1px solid ThreeDHighlight;
    border-right          : 1px solid ThreeDShadow;
    border-bottom         : 1px solid ThreeDShadow;
    padding               : 1px;
  }

scrollbarbutton:hover:active 
  {
    border                : 1px solid ThreeDShadow;
  }
  
scrollbarbutton:hover:active > .scrollbarbutton-box
  {
    border                : 1px solid ThreeDFace;
    padding               : 2px 0px 0px 2px;
  }   

scrollbarbutton[type="decrement"] 
  {
    list-style-image      : url("chrome://global/skin/scroll-left.gif")
  }

scrollbarbutton[type="decrement"][disabled="true"] 
  {
    list-style-image      : url("chrome://global/skin/scroll-left-disabled.gif") 
  }

scrollbarbutton[type="increment"] 
  {
    list-style-image      : url("chrome://global/skin/scroll-right.gif")
  }


scrollbarbutton[type="increment"][disabled="true"] 
  {
    list-style-image      : url("chrome://global/skin/scroll-right-disabled.gif") 
  }


scrollbarbutton[type="decrement"][sborient="vertical"]
  {
    list-style-image      : url("chrome://global/skin/scroll-up.gif")
  }

scrollbarbutton[type="decrement"][disabled="true"][sborient="vertical"]
  {
    list-style-image      : url("chrome://global/skin/scroll-up-disabled.gif") 
  }

scrollbarbutton[type="increment"][sborient="vertical"]
  {
    list-style-image      : url("chrome://global/skin/scroll-down.gif")
  }

scrollbarbutton[type="increment"][disabled="true"][sborient="vertical"]
  {
    list-style-image      : url("chrome://global/skin/scroll-down-disabled.gif") 
  }

slider 
  {
    background-color	    : Scrollbar;		
    background-image      : url("chrome://global/skin/scrollbar-slider-bg.gif");
  }
  
