

.box-toolbar-group
  {
    -moz-binding          : url("chrome://global/skin/classicBindings.xml#double-box");
    border-left           : 1px solid ThreeDShadow;
    border-top            : 1px solid ThreeDShadow;
    border-bottom         : 1px solid ThreeDHighlight;
    border-right          : 1px solid ThreeDHighlight;
    background-color      : -moz-field;
    margin                : 0px;
  }
  
.box-toolbar-group > .db-internal-box
  {
    border                : 1px solid ThreeDDarkShadow;
  }  
