/* stylesheet for XUL <radio> element */

/* default radio for dialogs */
/* outer frame */
  radio 
    {
      margin: 3px 5px 3px 5px;
    }

  radio > .internal-box
    {
      -moz-user-focus: none;
    }


/* checkmark outer frame */
  radio > .internal-box > .checkmark-box 
    {
      border: 1px solid #000000;
      -moz-border-radius: 50%;
      margin-top: 2px;
    }

  radio[disabled="true"] > .internal-box > .checkmark-box,
  radio[disabled="true"]:hover > .internal-box > .checkmark-box 
    {
      border: 1px solid #999999;
    }
    
/* checkmark inner frame */
  radio > .internal-box > .checkmark-box > image 
    {
      border: 1px outset #CCCCCC;
      width: 8px;
      height: 8px;
      -moz-border-radius: 50%;
    }

  /* ensure that no list-style-image is inherited in from the Outside */
  .checkmark-box
    {
      list-style-image: none;
    }
  

  radio[checked="true"] > .internal-box > .checkmark-box > image 
    {
      list-style-image: url(chrome://global/skin/check-radio.gif);
    }
  
  radio[checked="true"][disabled="true"] > .internal-box > .checkmark-box > image
    {
      list-style-image: url(chrome://global/skin/check-radio-disabled.gif);
    }

  radio:hover:active > .internal-box > .checkmark-box > image 
    {
      border: 1px inset #CCCCCC;
    }

  radio[disabled="true"] > .internal-box > .checkmark-box > image,
  radio[disabled="true"]:active > .internal-box > .checkmark-box > image 
    {
      border: 1px outset #CCCCCC;
    }

/* text/icon frames */
  radio[value] > .internal-box > html,
  radio.iconic > .internal-box > .icon 
    {
      margin: 0px 0px 0px 4px;
      padding: 1px;
    }

  radio.iconic > .internal-box > html 
    {
      margin-left: 4px;
    }
    
  radio[disabled="true"][value] > .internal-box > html 
    {
      color: #999999;
    }
  
  radio:focus > .internal-box > html
    { 
      border              : 1px dotted black;
      padding             : 0px;
    }
    
    