/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 */

.subscribedcol {
 list-style-image: url("chrome://messenger/skin/dot.gif");
}

.subscribedcol[value="true"] {
 list-style-image: url("chrome://messenger/skin/check.gif");
}

/* icons (newsgroup or mail folder) for the tree */

.tree-cell-subscribe-icon
{
 list-style-image: url("chrome://messenger/skin/folder-closed.gif");
}

.tree-cell-subscribe-icon[ServerType="nntp"] {
    list-style-image: url("chrome://messenger/skin/folder-newsgroup.gif");
}


/* for the server menu picker */

.subscribeMenuItem {
 list-style-image: url("chrome://messenger/skin/server-mail.gif");
}

.subscribeMenuItem[ServerType="imap"][IsSecure="true"] {
    list-style-image: url("chrome://messenger/skin/server-remote-lock.gif");
}

.subscribeMenuItem[ServerType="nntp"] {
    list-style-image: url("chrome://messenger/skin/server-news.gif");
}

.subscribeMenuItem[ServerType="nntp"][IsSecure="true"] {
    list-style-image: url("chrome://messenger/skin/server-news-lock.gif");
}

