#wiz-back-button {
  list-style-image            : url("chrome://global/skin/simple-arrow-left.gif");
}
#wiz-back-button[disabled] {
  list-style-image            : url("chrome://global/skin/simple-arrow-left-disabled.gif");
}
#wiz-next-button {
  list-style-image            : url("chrome://global/skin/simple-arrow-right.gif");
}
#wiz-next-button[disabled] {
  list-style-image            : url("chrome://global/skin/simple-arrow-right-disabled.gif");
}

box#wizardButtons {
  margin-top                  : 3px;
}

.box-wizardcontent
  {
    margin-left               : 44px;
    margin-right              : 44px;
    width                     : 30em;
  } 
