
#multi-results-header {
	background-color: #000000;
	color: #ffffff;; 
	font-weight: bold;
	padding: 5px 6px 5px 6px;
}

#engineTabs {
	/*don't know why its not setting the color*/
	background-color: #666666;
  padding-left: 3px;
}

#engineTabs > text {
	margin-top: 5px;
	color: white;
}

#engineTabs > titledbutton {
	-moz-border-radius: 8px 8px 0px 0px;
	margin-left: 5px;
	margin-right: 5px;
}