/********** Fonts ***************/

#sizeVar, #sizeMono {
	width: 4em;
}

#mouseWheelMode {
      width: 9em;
}

/******* SmartBrowsing **********/

#disabledDomains {
	max-height: 13em;
}

  
.smileface
  {
    list-style-image : url("chrome://messenger/skin/smile.gif");
  }
