
#finishtext {
  margin-top                  : -20px;
}

text#ProfileDir {
  font-weight                 : bold;
  padding-left                : 1em;
  margin-top                  : 0.4em;
}

box#dirbox > box > titledbutton {
  min-width                   : 8em;
}

span#deffoldername {
  margin-left                 : 2px;
} 
